@@ -6,10 +6,14 @@ c      ***************************************************************
 c
        subroutine sepics(ngen)
        implicit none
+#include  "ZepPos.h"
+#include  "Zep3Vec.h"
+#include  "Zswk.h"
        integer ngen  ! output. # of events generated in this run
 
        integer icon
-
+       
+       nevc = 0  ! for safety.  >=9.06
 c             init sepics, epics
        call sopen
 
@@ -348,9 +352,11 @@ c            for safety also set next
       character*80 msg
 
       integer jcon
+      integer nev ! >=9.06
 
-
-      if(nevc .ge. Nevent) then
+      call epqevn(nev)  ! >=9.06
+c      if(nevc .ge. Nevent) then  ! <=9.05
+      if(nev-1 .ge. Nevent) then  ! >=9.06
          icon=1
       else
 c                 get random no. for this event
@@ -398,6 +404,7 @@ c             end of 1 event
 #include  "Zswk.h"
           nevc=nevc+1
        end
+
 c     ***************
        subroutine sqtevn(nev)
        implicit none
@@ -420,6 +427,19 @@ c      *****************
              icon=0
           endif
        end
+
+      subroutine  sqCompEvents(ntried, ngenerated)
+      implicit none
+      integer,intent(out):: ntried      ! # of events tried to be generated
+      integer,intent(out):: ngenerated  ! # of events actually generated
+                   ! they may be differ if the user discard some
+                   ! events
+      call sqtevn(ntried)
+      call epqevn(ngenerated) 
+      ngenerated = ngenerated -1  ! -1 is for completely generated ones.
+      end
+
+
       subroutine ssetip( icon )
       implicit none
 #include  "ZsepManager.h"
@@ -465,7 +485,7 @@ c            multiple particles are incident; icon = 1--> end of a bunch
       record /epDirec/ norm
       character*40 msg
       real(8):: wl0 
-
+      real(8):: r2, r02, cb, dj
 
 c             set incident ptcl
 c               fix energy (momentum yet)
@@ -501,8 +521,9 @@ c               fix angle
                aTrack.w.x = DCInp.x
                aTrack.w.y = DCInp.y
                aTrack.w.z = DCInp.z
-            elseif(InputP .eq. 'usph' .or. InputP .eq. 'g->sph'
-     *           .or. InputP .eq. 'u->sph' ) then
+            elseif(InputP .eq. 'usph' .or.
+     *             InputP .eq. 'g->sph' .or.
+     *             InputP .eq. 'u->sph' ) then
 c                normal vector is the particle position to the center
                call epqwcoord(org, rxyz)
                norm.x =-( aTrack.pos.x - org.x )
@@ -613,7 +634,7 @@ c              inquire # of events created in this run
 c              print message
 c             get  current random no.
           call rnd1s(Ir1)
-          write(msg,*) ' # created in this run=',nev,
+          write(msg,*) ' # created in this run=',nev-1,
      *     ' current total #=',nevc,
      *     ' destination #=',Nevent,
      *     ' next ir=', Ir1
@@ -723,7 +744,6 @@ c               wait until angle is given
 c            For  negative HWHM, uniform distribution is employed
           call epgonSphere(1, -1.0d0, r, PosInp.x, PosInp.y, PosInp.z,
      *       aTrack.pos)
-
           aTrack.pos.x = aTrack.pos.x + org.x
           aTrack.pos.y = aTrack.pos.y + org.y
           aTrack.pos.z = aTrack.pos.z + org.z
