@@ -5,7 +5,7 @@ c
 #include  "Zcnfig.h"
 #include  "ZepManager.h"
       character*100  dsn1
-      MediaDir(1) = '../Data/Media'
+      MediaDir(1) = '$EPICSTOP/Data/Media'
       write(0,*) ' Enter path to the config file'
       read(*,'(a)') dsn1
       call eprcnf(dsn1)
