@@ -62,7 +62,9 @@ c           location of attribute characterizing a volume
         integer maxvertex    ! max number of vertexes of a given volume
                              !  that can be treated in Epics
         parameter (maxvertex =MAX_VERTEX)
-
+        integer maxtotcha    ! max characters in a line
+	  !  (concatinated if back slash exists)
+        parameter (maxtotcha = MAX_TOTCHA)
         real*8 MaxErrDirCos ! permissible error in sum of direction cos^2
         parameter( MaxErrDirCos = MAX_ERR_DIR_COS )
 
@@ -77,8 +79,22 @@ c  -------------------------------------------------------------------------
          real*8 orgx, orgy, orgz,
      *          direc(9)
          real   offsetx, offsety, offsetz, MaxPathL
-         character*8 struc, matter
+	  character(MAX_STRUCCHR)::struc
+          character(8):: matter
 	 real  rhoc  ! rho calibration factor 
+         real  EminG, EminE, RecoilE ! 
+         real  LengGmin, LengChmin 
+c            LengGmin: If length to the boundary is > this (cm)
+c                      gamma is regarded absorbed safely.
+c                 fixed by Ex = min(10keV, EminG) and attenuation
+c                 length in the media.
+c   
+c            LengChmin: If length to the boundary is > this(cm)
+c                   charged ptcl is regarded absorbed safely.
+c                   (but, anti-ptcl, decayable ptcl is not).
+c                 fixed by Ex=min(10keV, EminE-mass) and
+c                  dE/dx of media at Ex. 
+c            
 c         integer  Nattributes,
 c     *            NMatreska,
 c     *            NContainer, vol,
@@ -99,7 +115,7 @@ c            cn: component number assigned to this cmponent
 c )))))))))))
 
 
-         integer*2 NPContainer, CountIO,  CountDE
+       integer*2 NPContainer, CountIO,  CountDE, Modifier
 c  >>>>>>>>>>>>>>>>>>light        
          integer*2  LightCompNo
 c              LightCompNo; seq # given to light related comp
@@ -153,17 +169,18 @@ c       ********************
      *          comflag(maxcom), comloc 
 
 c
-#if defined IBMAIX
-        character*500  confdata
-#else
-        character*1024 confdata
-#endif
+!   #if defined IBMAIX
+!        character*500  confdata
+!   #else
+        character(maxtotcha):: confdata
+!   #endif
         character*80 comarea(maxcom)
-        character*24  Field(50), FieldAsItis(50)
+        character*24  Field(maxiattr), FieldAsItis(maxiattr)
         character*131 idis
         character*4 form
 c        character*8 SubDName(maxSubD),  PreDefName(NPreDefName)
         character*16 SubDName(maxSubD)
+        integer SubDUsedList(maxSubD)			      
         character*16 EqName(maxEq)
         real*8  EqValue(maxEq)
         integer Nequates
@@ -183,7 +200,7 @@ c
      2  EqValue, Volat,  VTXx, VTXy, VTXz, VolatEq,
      3  PosInDet, SubDNumb, SumOffset, subDwithID,  
      4  CnArea, comflag, CnCounter, AttrCounter, NVTX,
-     5  coment, Nequates, cumsubdloc,
+     5  coment, Nequates, cumsubdloc, SubDUsedList,
      6  Nfield, NsubD,  mode, SubDUsed, wrtcom, comcounter,
      7  comloc, Incused, ExistID,  EqualFshort
 
