@@ -28,14 +28,15 @@
       !  derived attribues in the program).
 
 #define MAX_VERTEX  40
-       !     max nubmer of vertexes of a component treatable.
+       !     max number of vertexes of a component treatable.
        !     If a volume has a  curved surface (convex), vertex
        !     information is not used; NVTX=0 
-
-#define MAX_SUBD  2000
-
+#define MAX_TOTCHA 2048
+       !    max number of total characters in a line.
+       !    A line includes concatinated lines by backslash
+#define MAX_SUBD  2000  
        !     max number of sub-detectors definable
-#define MAX_COMPONENT_IN_SUBD  80000
+#define MAX_COMPONENT_IN_SUBD  200000
        !     max number of components in a sub detector
 #define MAX_SUBD_REF  2000
        !     max number of sub detectors that can be referred
