@@ -43,6 +43,13 @@ cc                 !
             real*8  A     ! sum No x  Ai
             real*8  Z     ! sum No x  Zi
             real*8  Z2    ! sum No x  Zi**2
+            real*8  ZZ1   ! sum No x  Zi(Zi+1)
+               ! for electron;  this * t /(gamma beta2)^2 = Xc^2 (t g/cm2)
+            real*8  MoliereForXc2
+            real*8  MoliereExpb !  exp(b) = t x this  (t in g/cm2)a
+                  ! for z=1 and beta =1.          
+                  ! this  = 6702 sum/A
+                  !    sum = Sum No x Zi^(1/3)(Zi+1)/(1+3.327(Ziz/137)^2)
             real*8  Z1_3rd !  <Z^1/3>  not <Z>^(1/3)
             real*8  Z2_3rd !  <Z^2/3>  not <Z>^(2/3) 
             real*8  mbtoPgrm ! 10^-27 x N0/A. If multiplied to sigma in mb,
@@ -77,6 +84,7 @@ c               a compound /molecule as an atom
             integer gasF  ! flag for gas. If  1, media is gas,  0 -->solid
             character*8  name  ! name of media
             integer  format    ! format of the  basic table. (1 or 2)
+
             real*8  s1         ! Migdal's s1
             real*8  logs1      ! log(s1) 
             real*8  basearea   ! pi x Re**2 * N* Z /A *X0g  = 0.15 Z/A*X0g
@@ -84,9 +92,37 @@ c               a compound /molecule as an atom
                                ! crossection
             real*8  cScrC2     ! the other such one
             real*8  cScrMain   ! (4/3C1 + C2)
-            real*8  BirksC1    ! Birks' C1 (13 g/GeV/ cm2) for organic scinit.
-            real*8  BirksC2    ! //     C2 (9.6 (g/GeV/cm2)^2 ..
-            real*8  BirksCC    ! // correction factor for C1 for heavy particles (0.5714)
+            real*8  BirksC1    !  quenching correction coef.
+            real*8  BirksC2    !  //
+            real*8  BirksCC    !  //
+            character(1)::Birks ! flag to identify what quenching correction
+                                ! should be applied using BirksC1, etc.
+              !  In the media  data,  data format  for c1, c2, cc is one of 
+              !  a)  c1 c2 cc   (none zero or all zero)
+              !  b)  c1 c2 cc  B
+              !  c)  c1 c2  T
+              !  d)  c1 c2 cc  L 
+              !  a) is old format. all  0 means no quencthing.
+              !     if not so, or b) format case,  only c1 will be used
+              !     as the original formula by Birks
+              !         dE/dx|q =  dE/dx/(1+c1*dE/dx)
+              !     e.g. c1 (13 g/cm2/GeV) for organic scinit 
+              !          c2 (9.6 (g/GeV/cm2)^2 .. is intended to use
+              !       (1 + c1 X + c2*X**2) as the denominator.
+              !       where X is dE/dx in GeV/(g/cm2). 
+              !      cc is the correction factor for heavy particles
+              !       (e.g 0.5714).  c2 and cc are not used in Epics
+              !  c)  Tarle's formula  dE/dx|q = (1-c2)X/( 1+c1(1-c2)X) + c2X
+              !              c1 in (g/cm2)/GeV. c2 simple number
+              !         if fitting is done in another unit, simply change c1
+              !         (say, if X is MeV/(g/cm2), C1*1000 -->c1)
+              !  d)  Log formula
+              !      dE/dx|q = X * (cc*X)**(-c2*log(c1*X))
+              !      c1, cc  in g/cm2/GeV c2 simple number.
+              !      if fitting is done in another unit, change 
+              !      c1 and cc. (e.g if in MeV/(g/cm2). C1*1000->c1
+              !      CC*1000->cc
+            integer srim   !  index for srim data in module srimdata
             record /bpTbl/  tbl
             record /sternh/ sh
             record /SmpCnst/ cnst
@@ -95,4 +131,3 @@ c               a compound /molecule as an atom
             record /mubpn/ mu 
             record /epxcom/ xcom
          end structure
-
