@@ -6,7 +6,7 @@
 #define IMAG_P imag
 #endif
       
-c      kinout:  judge if a point is inside of a polygon
+
 c      kxplbx:  box and line x-point
 c      kxplcy:  cyl and line x-point
 c      kxplp:   plane and line x-point
@@ -296,191 +296,6 @@ c                 no cross
           endif
       endif
       end
-c*include kxplsl
-c          test kinout
-c      real xa(5), ya(5)
-c      data xa/-1., 1., 1.5, 0.,  -1./, ya/-1., -1., 0., 1., 1./
-c      x0=-0.5
-c      y0=0.2
-c      eps=1.e-5
-c      call kinout(xa, 1, ya, 1, 5, x0, y0, eps, 'conv', icon)
-c      write(*,*) ' icon=',icon
-c      end
-c     ****************************************************************
-c     *                                                              *
-c     *  kinout: judge whether a given point is in inner or outer    *
-c     *          region of a given polygon.                          *
-c     ****************************************************************
-c
-c /usage/  call kinout(xa, intvx, ya, intvy, n, x0, y0, eps,
-c        *     convex, icon)
-c    xa:   input.  real*8. array containe x values of a polygon
-c    ya:   input.  real*8   //       y
-c  intvx:  input.  integer*4.  interval of data in xa
-c  intvy:  input.  //                              ya
-c      n:  input.  # of polygon vertexes.
-c  x0,y0:  input.  real*8 point to be judged whether it is inside
-c                  of the polygon
-c    eps:  input.  accuracy to judge //ity or coincident lines.
-c convex:  input.  'conv'->polygon is assumed to be convex, else it
-c                  may be convex or concave.
-c   icon:  output.   1 if the point is in outer region
-c                   -1                 in inner region
-c                    0  on the edge of the polygon
-c                   -2 input is invalid (n<=2)
-c
-c method:  draw an arbitrary half-line from (x0,y0), which does
-c         not pass the vertex of the polygon.  if it crosses the
-c         polygon edge odd TimeStruc, (x0,y0) is in inner part.
-c
-c        if two consEcutive points of polygon are same, one of them
-c        will be ignored.  if resultant vertex points become <=2,
-c        icon=-2 will result.
-c
-c  ***   kxplsl needed.   ***
-c
-c
-c
-c
-       subroutine  kinout(xa, intvx, ya, intvy, n, x0, y0, eps,
-     *         convex, icon)
-       implicit none
-c
-
-       character*(*) convex
-       integer intvx, intvy, n, icon
-       real*8 xa, ya, x0, y0, eps
-       dimension xa(intvx,n), ya(intvy,n)
-c
-      complex*16 expa
-      complex*16 expaa(4)/ (1.,0.), (0., 1.), (0.,-1.), (-1., 0.)/
-      integer j, ic, i
-      real*8 angle
-c
-      if(n .le. 2 .or. intvx .le. 0 .or. intvy .le. 0)then
-         icon=-2
-      else
-         j=1
-c         *** until loop*** 
-         do while (.true.)
-c             choose angle of half-line starting from (x0,y0)
-             expa=expaa(j)
-             call kinoua(xa, intvx, ya, intvy, n, x0, y0, eps,
-     *       convex, expa,  icon)
-c             write(*,*) ' icon=',icon, ' j=',j
-             j=j+1
-         if         (icon .ge. -2 .or. j .gt. 4)
-     *                      goto 200
-         enddo
-  200    continue
-        if(icon .lt. -2) then
-c               parallel to cordinate lines have been all tested,
-c               so try inclined half-line starting from angle=10 deg.
-c               with step 10 deg
-             ic=0
-c             *** until loop*** 
-             do while (.true.)
-                  if(mod(ic, 4) .eq. 0) then
-                     angle=0.1745329*(ic+1)
-                  endif
-                  expa = exp((0.d0,1.d0)*angle)
-                  call kinoua(xa, intvx, ya, intvy, n, x0, y0, eps,
-     *            convex, expa,  icon)
-                  angle=angle+3.14159265/2
-                  ic=ic+1
-             if         (icon .ge.-2 .or. ic .gt. 10)
-     *                          goto 300
-             enddo
-  300        continue
-             if(icon .lt. -2) then
-             write(*,810) convex,x0, y0, (xa(1,i),ya(1,i), i=1,n)
-  810          format('0***ill-condition input to kinout.  convex=',a4,
-     1        '  x0,y0=',2g13.4, ' vertex points=',/(1h ,10g12.3))
-               icon=-2
-             endif
-         endif
-      endif
-      end
-      subroutine kinoua(xa, intvx, ya, intvy,n, x0, y0, eps,
-     *  convex,  expa, icon)
-       implicit none
-       character*(*) convex
-       integer intvx, intvy, n, icon
-       real*8 xa, ya, x0, y0, eps
-       dimension xa(intvx,n), ya(intvy,n)
-       complex*16  z1, z2, expa, z00
-       real*8 xx1(2), xx2(2)
-       equivalence ( xx1(1), z1 ), ( xx1(1), x1 ), ( xx1(2), y1 ),
-     1            ( xx2(1), z2 ), ( xx2(1), x2 ), ( xx2(2), y2 )
-       integer nor
-       real*8 x1, y1, x2, y2, p, q
-       integer i, jcon, nn
-c
-       z00=cmplx(x0,y0)
-c        clear no. of crossing points of this line with the polygon
-       nor=0
-c         vertex ponts counter
-       nn=n
-       i=1
-       icon=-3
-c       *** until loop*** 
-       do while (.true.)
-c          choose two points to form a segment
-          x1=xa(1,i)
-          y1=ya(1,i)
-          if( i .eq. n) then
-              x2=xa(1,1)
-              y2=ya(1,1)
-          else
-              x2=xa(1,i+1)
-              y2=ya(1,i+1)
-          endif
-c             see if two vertex points are same
-          if(x1 .eq. x2 .and. y1 .eq. y2) then
-c              reduce vertex points counter
-             nn=nn-1
-             if(nn .le. 2) then
-                icon=-2
-             endif
-          else
-c                obtaine cross point of two lines
-             call kxplsl(z00, expa, z1, z2, eps, p, q, jcon)
-c            write(*,*) ' kxplsl: jcon=',jcon, ' p=',p, ' q=',q
-             if(jcon .eq. 0) then
-c                   crossing point exist
-c                    see if z0 is on the polygon edge
-                   if( abs(q) .le. eps) then
-c                           given point is on the polygon edge
-                       icon=0
-                   elseif( q .lt. 0.) then
-c                       see if cross point is not on the half line
-c                         try antther
-                   elseif( p .eq. 0.  .or. p .eq. 1. ) then
-c                    if cross point is on the vertex, take another line
-                      i=n+1
-                      icon=-3
-                   else
-                      nor=nor+1
-                      if(convex .eq. 'conv'  .and. (nor .eq. 2) ) then
-c                        if convex, max of nor is 2
-                         icon=1
-                      endif
-                   endif
-             elseif(jcon .eq. 1) then
-c                  overlap
-                 i=n+1
-             elseif(jcon .ge. 2) then
-c                // or no x on the seg.
-             endif
-          endif
-          i=i+1
-       if         (i .gt. n .or. icon .ge.-2)
-     *                    goto 100
-       enddo
-  100  continue
-c     write(*,*) ' nor=',nor
-      if(nor .ge. 1 .and. mod(nor,2) .ne. 0) icon=-1
-      end
 c     complex zz0/(0., 0.)/
 c     complex expa, zz1, zz2
 c     expa=exp( cmplx(0., 1.)*(90.01 /180.*3.141592 ) )
@@ -764,12 +579,12 @@ c
         if(icon .eq. 0) then
             if(el1 .gt. 0.) then
                 if(el2 .gt. 0.) then
-                   if(min(el1, el2)/max(el1, el2) .lt. eps) then
-                      el = max(el1, el2)
-                   else
+c                   if(min(el1, el2)/max(el1, el2) .lt. eps) then
+c                      el = max(el1, el2)
+c                   else
                       el=min(el1, el2)
                       icon=1
-                   endif
+c                   endif
                 elseif(el2 .le. 0.) then
                     el=el1
                     icon=0
@@ -1350,339 +1165,6 @@ c      shift ichrs to left until next blank appear  and stores it into ochrs
        icon = 1
  100   continue
        end
-c      implicit none
-c      real*8  x, y, z  
-c      real*8  a, b, c, h 
-c      integer  icon 
-c                    
-c
-c      write(0, *) ' enter x,y,z, a, b, c, h'
-c      read(*, *)  x,y,z, a, b, c, h
-c      call kioPrism(x,y, z, a, b, c, h, icon)
-c      write(*,*) icon
-c      end
-      subroutine kioPrism(x, y, z, a, b, c, h, icon)
-c       judge if (x,y,z) is inside of a given prism
-c       or not.
-c
-      implicit none
-      real*8  x, y, z  ! input. a given point
-      real*8  a, b, c, h ! input.  const to characterize a prism
-      integer  icon  !  output.  icon =0.  the point is inside or
-                     !            on the surface
-                     !                +1   outside.
-
-c          
-c           | z
-c           |           *
-c           |         * |    + 
-c           |       *   |         + 
-c           |     *     h            +
-c           |   *       |                 +
-c           | *         |                      +
-c           |___________|__________________________+   x
-c           0           c                          a
-c           
-c          b is the depth on the y axis.
-c  a, b,  c,  h can be negative.
-c
-c      
-c
-      integer jcon
-
-c         see if y is inbetween 0,b
-      if( (b-y)*y .ge.  0.d0) then
-c           see if (x,z) is in the triagle
-         call k3inout(x, z, 0.d0, 0.d0, a, 0.d0, c, h, jcon)
-
-         if(jcon .eq. 0)  then
-            icon = 0
-         else
-            icon = 1
-         endif
-      else
-         icon = 1
-      endif
-      end
-      subroutine kxplPrism(x0, y0, z0, l, m, n, 
-     *            a, b, c, h , el, cond)
-c         get the length to the nearest crossing point
-c    of a given line with a given prism.
-c
-      real*8 x0, y0, z0  ! input.  the line passes this point
-      real*8 l, m, n     ! input.  the line's direction cosine
-      real*8 a, b, c, h  ! input.  prism parameter
-      real*8 el          ! output. length to the crossing point
-                         !         (only el>=0 is obtained)
-      integer cond       ! output. =0, the point is inside or on 
-                         !             the surface. el was obtained.
-                         !         =1, the point is outside.
-                         !             el was obtained.
-c                        !         =-1  no crossing point.  el undef.
-c     Z
-c     |
-c     |        *
-c     |       *|    +
-c     |      * |        + 
-c     |     *  |            +
-c     |    *   |                +
-c     |   *    h                    + 
-c     |  *     |                        +  
-c     |________|___________________________+  X
-c     0        c                           a 
-c         b is depth along y.
-c
-c      a,b,c,h can be negative.
-c
-      real*8 x, y, z, el1, temp, eps
-      integer inout
-      character*120 msg
-
-
-      data eps/-1.d-12/
-
-
-c
-
-c
-c        x:  0~a is not necesarrily the range but x1~x2.
-      x1 = min(0.d0, a, c)
-      x2 = max(0.d0, a, c)
-c         judge if (x0,.)  is inside
-      call kioPrism(x0, y0, z0, a, b, c, h, cond)
-
-      if(cond .eq. 0) then
-c           inside
-c          cross with the x-y plane ?
-         if(n .ne.  0.d0) then
-            el = -z0/n
-         elseif(z0 .eq. 0.d0) then
-            el = 0.
-         else
-            el = -1.    !  to skip next if
-         endif
-         if(el .ge. 0.d0) then
-            x = x0 + el* l
-            y = y0 + el* m
-c             if (x,y) is inside the bottom, el obtained
-            if( x*(a-x) .ge. eps  .and.
-     *          (b-y)*y .ge. eps ) goto 10
-         endif
-c              cross with  / ?
-         temp = c*n-h*l
-         if(temp .ne. 0.d0) then
-            el = (h*x0 - c*z0)/temp
-
-         elseif( (h*x0 - c*z0) .eq. 0.d0) then
-            el = 0.
-         else
-            el = -1.  ! this is to skip next if
-         endif
-         if(el .ge. 0.d0) then
-            z = z0 + el * n
-c               z : inbetween 0~h
-            if( (h-z)*z .ge. 0.d0) then
-               x = x0 + el * l
-               if( x* (c - x) .ge. eps) then
-                  y = y0 + el * m
-                  if( (b-y)*y .ge. 0.) goto 10
-               endif
-            endif
-         endif
-c          cross with \ ?
-         temp = h*l-(c-a)*n
-         if(temp .ne. 0.d0) then
-            el =(a*h- h*x0 + z0*(c-a))/temp
-         elseif((a*h- h*x0 + z0*(c-a)) .eq. 0.d0) then
-            el = 0.
-         else
-            el = -1.  ! to skip next
-         endif
-         if(el .ge. 0.d0) then
-            z = z0 + el * n
-            if( (h-z)*z .ge. eps) then
-               x = x0 + el * l
-               if( (c - x)* (x - a) .ge. 0.d0) then
-                  y = y0 + el * m
-                  if( (b-y)*y .ge. eps) goto 10
-               endif
-            endif
-         endif
-c           cross with x-z plane at y=0
-         if(m .ne. 0.d0) then
-            el = - y0/m
-         elseif(y0 .eq. 0.d0) then
-            el = 0.
-         else
-            el = -1.    ! to skip next if
-         endif
-         if(el .ge. 0.d0) then
-            x = x0 + el * l
-            z = z0 + el * n
-            call k3inout(x, z, 0.d0, 0.d0, a, 0.d0, c, h, inout)
-            if(inout .eq. 0) goto 10
-         endif
-c             cross with x-z plone at y=b  ?
-         if(m .ne. 0.d0) then
-            el = (b-y0)/m
-         elseif(b .eq. y0)  then
-            el = 0.
-         else
-            el  = -1.  ! to skip next if
-         endif
-         if(el .ge. 0.d0) then
-            x = x0 + el * l
-            z = z0 + el * n
-            call k3inout(x, z, 0.d0, 0.d0, a, 0.d0, c, h, inout)
-            if(inout .eq. 0) goto 10
-         endif
-c           error
-         call 
-     *   cerrorMsg('kxplPrism; point is inside but no x.p',1)
-         write(msg, *) 'x0..=',x0,y0,z0, ' lmn=',l,m,n
-         call cerrorMsg(msg, 0)
-      else
-c        ***********************************************
-c         point is outside. firstly, judge no crossing
-c         possiblity quickly
-c
-         cond = - 1
-
-c            see if crossing point cannot be in the xrange.
-c          For X point  to eixt inbetween x1,x2
-c          f(el)=  (el*l - (x1-x0))(el*l -(x2-x0)) <= 0
-c          must be sutisfied for some el >=0.
-c          If there is no el >=0, there is no possibility of
-c          crossing.
-c          That  condtions is:
-c                 for f(0) > 0 and  (x1-x0)/l < 0
-c             (l !=0) .  if l=0,  f(0) > 0 is enough
-         if((x1-x0)*(x2-x0) .gt. 0.d0 .and.
-     *         (x1-x0)*l .le. 0.d0) goto 10
-c            see if crossing point cannot be in the yrange
-         if( (b-y0)*(-y0) .gt. 0.d0 .and.
-     *       (b-y0)*m .le. 0.d0) goto 10
-c            see if crossing point cannot be in the zrange
-         if( (h -z0)*(-z0) .gt. 0.d0  .and.
-     *              (h -z0)*n .le.0.d0) goto 10
-c
-c             there is a possibilty of crossing
-         
-         nc = 0          ! crossing point counter
-c          see x.p on (x-y) 
-         if(n .ne. 0.d0) then
-            el = - z0/n
-            if(el .ge. 0.d0) then
-               x  = x0 + el *l
-               y  = y0 + el *m
-               if( x *(a-x) .ge. eps ) then
-                  if( (b-y)* y .ge. eps ) then
-                     nc = 1
-                     el1 = el
-                  endif
-               endif
-            endif
-c        else
-c            this case should be inside if x.p exists
-         endif
-c           see x.p on /
-         temp = c*n - h*l
-         if(temp .ne. 0.) then
-            el =  (h*x0 - c*z0)/temp
-            if(el .ge. 0.d0) then
-               x = x0 + el*l
-               y = y0 + el*m
-               z = z0 + el*n
-               if( x*(c-x) .ge. eps .and.
-     *              y*(b-y) .ge.  eps  .and.
-     *              z*(h-z) .ge.  eps ) then 
-
-                  if(nc .eq. 0) then
-                     el1 = el
-                     nc = 1
-                  else
-                     el = min(el, el1)
-                     cond = 1
-                     goto 10
-                  endif
-               endif
-            endif
-c         else
-c               this should not happen--> inside case
-         endif
-c
-c              \ case
-         temp = h*l -(c-a)*n
-         if(temp .ne. 0.) then
-            el =( a*h - h*x0 + (c-a)*z0 )/temp
-
-            if(el .ge. 0.d0) then
-               x = x0 + el*l
-               y = y0 + el*m
-               z = z0 + el*n
-               if( (x-c)*(a-x) .ge. eps .and.
-     *              y*(b-y) .ge.  eps  .and.
-     *              z*(h-z) .ge.  eps ) then 
-
-                  if(nc .eq. 0) then
-                     nc = 1
-                     el1 = el
-                  else
-                     el = min(el, el1)
-                     cond = 1
-                     goto 10
-                  endif
-               endif
-            endif
-c         else
-c           this case; no need be checked.
-         endif
-c            cross with  x-z at y=0
-         if(m .ne. 0.d0) then
-            el = - y0/m
-            if(el .ge. 0.d0) then
-               x = x0 + el *l
-               z = z0 + el *n
-               call k3inout(x, z, 0.d0, 0.d0, a, 0.d0,
-     *                     c, h, inout)
-               if(inout .eq. 0) then
-                  if(nc .eq. 0) then
-                     nc = 1
-                     el1 = el
-                  else
-                     el = min(el1, el)
-                     cond = 1
-                     goto 10
-                  endif
-               endif
-            endif
-c        else
-c           not coming here 
-         endif
-c          cross with x-z y=b
-         if(m .ne.  0.d0) then
-            el = (b-y0)/m
-            if(el .ge. 0.d0) then
-               x = x0 + el *l
-               z = z0 + el *n
-               call k3inout(x, z, 0.d0, 0.d0,
-     *         a, 0.d0, c, h, inout)
-               if(nc .eq. 0) then
-                  nc = 1
-                  el1 =  el
-               else
-                  el = min(el1, el)
-                  cond = 1
-                  goto 10
-               endif
-            endif
-c        else
-c           not coming here 
-         endif
-         cond = -1
-      endif
- 10   continue
-      end
 c      real*8 kDebye, x
 c      integer i
 c      x = 0.
@@ -2132,7 +1614,8 @@ c*****************************************
       subroutine kgsub(r, t, si, so)
       implicit none
 c        replace stgring r in si by t and put so
-c     
+c        old kgsub has bug if t is "" or " " ...
+
       character*(*)  r  ! input.
       character*(*)  t  ! input.
       character*(*)  si ! input.
@@ -2140,9 +1623,11 @@ c
 
       integer klena, ir, it, isi, iso, i, j
 
-      ir = klena(r)
-      it = klena(t)
-      isi = klena(si)
+      ir = len(trim(r))
+      it = len(trim(t))
+      if(it == 0 ) it = len(t)
+
+      isi =len(trim(si))
       iso = len(so)
       
       i = 1
@@ -2152,17 +1637,27 @@ c
          if(i+ir-1 .le. isi) then
             if( si(i:i+ir-1) .eq. r(1:ir)) then
                j = j + 1
-               so(j:j+it-1) = t(1:it)
-               j = j + it -1
+               if(it > 0 )  then
+                  so(j:j+it-1) = t(1:it)
+                  j = j + it -1
+               endif
                i = i + ir
             else
                j = j + 1
-               so(j:j+it-1) = si(i:i)
+               if( it> 0 ) then
+                  so(j:j+it-1) = si(i:i)
+               else
+                  so(j+it-1:J) = si(i:i)
+               endif
                i = i + 1
             endif
          else
             j = j + 1 
-            so(j:j+it-1) = si(i:i)
+            if(it > 0 ) then
+               so(j:j+it-1) = si(i:i)
+            else
+               so(j+it-1:j) = si(i:i)
+            endif
             i = i +1
          endif
          if(j .gt. iso) then
@@ -2172,7 +1667,354 @@ c
          endif
       enddo
       end
+!      implicit none
+!      real*8  x, y, z, el, l, m, n
+!      real*8  a, b, c, h 
+!      integer  icon, cond 
+!cc                    
+!c
+!cc      write(0, *) ' enter x,y,z, a, b, c, h'
+!cc      read(*, *)  x,y,z, a, b, c, h 
+!       x = 19.3364132663471d0       
+!       y = 0.351801084456073d0    
+!       z =  -14.7246124670421d0 
+!       a = 28.2000000000000d0      
+!       b= 1.00000000000000d0     
+!       c = 28.2000000000000d0      
+!       h =      -28.2000000000000d0
+!c
+!      call kioPrism(x,y, z, a, b, c, h, icon)
+!      write(*,*) icon
+!c
+!      l= 0.730182332808807d0 
+!      m =  1.901783791699804d-002
+!      n = -0.682987616600244d0     
+!c
+!      call kxplPrism(x, y, z, l, m, n, 
+!     *            a, b, c, h , el, cond)
+!cc         get the length to the nearest crossing point
+!      write(0,*) el, cond
+!      end
+      subroutine kioPrism(x, y, z, a, b, c, h, icon)
+c       judge if (x,y,z) is inside of a given prism
+c       or not.
+c
+      implicit none
+      real*8  x, y, z  ! input. a given point
+      real*8  a, b, c, h ! input.  const to characterize a prism
+      integer  icon  !  output.  icon =0.  the point is inside or
+                     !            on the surface
+                     !                +1   outside.
+
+c          
+c           | z
+c           |           *
+c           |         * |    + 
+c           |       *   |         + 
+c           |     *     h            +
+c           |   *       |                 +
+c           | *         |                      +
+c           |___________|__________________________+   x
+c           0           c                          a
+c           
+c          b is the depth on the y axis.
+c  a, b,  c,  h can be negative.
+c
+c      
+c
+      integer jcon
+
+c         see if y is inbetween 0,b
+      if( (b-y)*y .ge.  0.d0) then
+c           see if (x,z) is in the triagle
+         call k3inout(x, z, 0.d0, 0.d0, a, 0.d0, c, h, jcon)
+
+         if(jcon .eq. 0)  then
+            icon = 0
+         else
+            icon = 1
+         endif
+      else
+         icon = 1
+      endif
+      end
+      subroutine kxplPrism(x0, y0, z0, l, m, n, 
+     *            a, b, c, h , el, cond)
+c         get the length to the nearest crossing point
+c    of a given line with a given prism.
+c
+      real*8 x0, y0, z0  ! input.  the line passes this point
+      real*8 l, m, n     ! input.  the line's direction cosine
+      real*8 a, b, c, h  ! input.  prism parameter
+      real*8 el          ! output. length to the crossing point
+                         !         (only el>=0 is obtained)
+      integer cond       ! output. =0, the point is inside or on 
+                         !             the surface. el was obtained.
+                         !         =1, the point is outside.
+                         !             el was obtained.
+c                        !         =-1  no crossing point.  el undef.
+c     Z
+c     |
+c     |        *
+c     |       *|    +
+c     |      * |        + 
+c     |     *  |            +
+c     |    *   |                +
+c     |   *    h                    + 
+c     |  *     |                        +  
+c     |________|___________________________+  X
+c     0        c                           a 
+c         b is depth along y.
+c
+c      a,b,c,h can be negative.
+c
+      real*8 x, y, z, el1, temp, eps
+      integer inout
+      character*120 msg
 
 
-      
-      
+      data eps/-1.d-12/
+
+
+c
+
+c
+c        x:  0~a is not necesarrily the range but x1~x2.
+      x1 = min(0.d0, a, c)
+      x2 = max(0.d0, a, c)
+c         judge if (x0,.)  is inside
+      call kioPrism(x0, y0, z0, a, b, c, h, cond)
+
+      if(cond .eq. 0) then
+c           inside
+c          cross with the x-y plane ?
+         if(n .ne.  0.d0) then
+            el = -z0/n
+         elseif(z0 .eq. 0.d0) then
+            el = 0.
+         else
+            el = -1.    !  to skip next if
+         endif
+         if(el .ge. 0.d0) then
+            x = x0 + el* l
+            y = y0 + el* m
+c             if (x,y) is inside the bottom, el obtained
+            if( x*(a-x) .ge. eps  .and.
+     *          (b-y)*y .ge. eps ) goto 10
+         endif
+c              cross with  / ?
+c             (x-x0)/l = (z-z0)/n;  at 
+         temp = c*n-h*l
+         if(temp .ne. 0.d0) then
+            el = (h*x0 - c*z0)/temp
+         elseif( (h*x0 - c*z0) .eq. 0.d0 ) then
+            el = 0.
+         else
+            el = -1.  ! this is to skip next if
+         endif
+         if(el .ge. 0.d0) then
+            z = z0 + el * n
+c               z : inbetween 0~h
+            if( (h-z)*z .ge. eps) then  !!
+               x = x0 + el * l
+               if( x* (c - x) .ge. eps) then
+                  y = y0 + el * m
+                  if( (b-y)*y .ge. eps) goto 10   !!
+               endif
+            endif
+         endif
+c          cross with \ ?
+         temp = h*l-(c-a)*n
+         if(temp .ne. 0.d0) then
+            el =(a*h- h*x0 + z0*(c-a))/temp
+         elseif((a*h- h*x0 + z0*(c-a)) .eq. 0.d0) then  
+            el = 0.
+         else
+            el = -1.  ! to skip next
+         endif
+         if(el .ge. 0.d0) then
+            z = z0 + el * n
+            if( (h-z)*z .ge. eps) then
+               x = x0 + el * l
+               if( (c - x)* (x - a) .ge. eps) then   !!
+                  y = y0 + el * m
+                  if( (b-y)*y .ge. eps) goto 10
+               endif
+            endif
+         endif
+c           cross with x-z plane at y=0
+         if(m .ne. 0.d0) then
+            el = - y0/m
+         elseif(y0 .eq. 0.d0) then
+            el = 0.
+         else
+            el = -1.    ! to skip next if
+         endif
+         if(el .ge. 0.d0) then
+            x = x0 + el * l
+            z = z0 + el * n
+            call k3inout(x, z, 0.d0, 0.d0, a, 0.d0, c, h, inout)
+            if(inout .eq. 0) goto 10
+         endif
+c             cross with x-z plone at y=b  ?
+         if(m .ne. 0.d0) then
+            el = (b-y0)/m
+         elseif(b .eq. y0)  then
+            el = 0.
+         else
+            el  = -1.  ! to skip next if
+         endif
+         if(el .ge. 0.d0) then
+            x = x0 + el * l
+            z = z0 + el * n
+            call k3inout(x, z, 0.d0, 0.d0, a, 0.d0, c, h, inout)
+            if(inout .eq. 0) goto 10
+         endif
+c           error
+         call  cerrorMsg(
+     *    'kxplPrism; point is inside but no x.p',1)
+         write(0, *) 'x0,y0,z0=',x0,y0,z0, ' lmn=',l,m,n
+         write(0, *) 'a, b, c, h =',  a,b,c,h
+         stop
+      else
+c        ***********************************************
+c         point is outside. firstly, judge no crossing
+c         possiblity quickly
+c
+         cond = - 1
+
+c            see if crossing point cannot be in the xrange.
+c          For X point  to eixt inbetween x1,x2
+c          f(el)=  (el*l - (x1-x0))(el*l -(x2-x0)) <= 0
+c          must be sutisfied for some el >=0.
+c          If there is no el >=0, there is no possibility of
+c          crossing.
+c          That  condtions is:
+c                 for f(0) > 0 and  (x1-x0)/l < 0
+c             (l !=0) .  if l=0,  f(0) > 0 is enough
+         if((x1-x0)*(x2-x0) .gt. 0.d0 .and.
+     *         (x1-x0)*l .le. 0.d0) goto 10
+c            see if crossing point cannot be in the yrange
+         if( (b-y0)*(-y0) .gt. 0.d0 .and.
+     *       (b-y0)*m .le. 0.d0) goto 10
+c            see if crossing point cannot be in the zrange
+         if( (h -z0)*(-z0) .gt. 0.d0  .and.
+     *              (h -z0)*n .le.0.d0) goto 10
+c
+c             there is a possibilty of crossing
+         
+         nc = 0          ! crossing point counter
+c          see x.p on (x-y) 
+         if(n .ne. 0.d0) then
+            el = - z0/n
+            if(el .ge. 0.d0) then
+               x  = x0 + el *l
+               y  = y0 + el *m
+               if( x *(a-x) .ge. eps ) then
+                  if( (b-y)* y .ge. eps ) then
+                     nc = 1
+                     el1 = el
+                  endif
+               endif
+            endif
+c        else
+c            this case should be inside if x.p exists
+         endif
+c           see x.p on /
+         temp = c*n - h*l
+         if(temp .ne. 0.) then
+            el =  (h*x0 - c*z0)/temp
+            if(el .ge. 0.d0) then
+               x = x0 + el*l
+               y = y0 + el*m
+               z = z0 + el*n
+               if( x*(c-x) .ge. eps .and.
+     *              y*(b-y) .ge.  eps  .and.
+     *              z*(h-z) .ge.  eps ) then 
+
+                  if(nc .eq. 0) then
+                     el1 = el
+                     nc = 1
+                  else
+                     el = min(el, el1)
+                     cond = 1
+                     goto 10
+                  endif
+               endif
+            endif
+c         else
+c               this should not happen--> inside case
+         endif
+c
+c              \ case
+         temp = h*l -(c-a)*n
+         if(temp .ne. 0.) then
+            el =( a*h - h*x0 + (c-a)*z0 )/temp
+
+            if(el .ge. 0.d0) then
+               x = x0 + el*l
+               y = y0 + el*m
+               z = z0 + el*n
+               if( (x-c)*(a-x) .ge. eps .and.
+     *              y*(b-y) .ge.  eps  .and.
+     *              z*(h-z) .ge.  eps ) then 
+
+                  if(nc .eq. 0) then
+                     nc = 1
+                     el1 = el
+                  else
+                     el = min(el, el1)
+                     cond = 1
+                     goto 10
+                  endif
+               endif
+            endif
+c         else
+c           this case; no need be checked.
+         endif
+c            cross with  x-z at y=0
+         if(m .ne. 0.d0) then
+            el = - y0/m
+            if(el .ge. 0.d0) then
+               x = x0 + el *l
+               z = z0 + el *n
+               call k3inout(x, z, 0.d0, 0.d0, a, 0.d0,
+     *                     c, h, inout)
+               if(inout .eq. 0) then
+                  if(nc .eq. 0) then
+                     nc = 1
+                     el1 = el
+                  else
+                     el = min(el1, el)
+                     cond = 1
+                     goto 10
+                  endif
+               endif
+            endif
+c        else
+c           not coming here 
+         endif
+c          cross with x-z y=b
+         if(m .ne.  0.d0) then
+            el = (b-y0)/m
+            if(el .ge. 0.d0) then
+               x = x0 + el *l
+               z = z0 + el *n
+               call k3inout(x, z, 0.d0, 0.d0,
+     *         a, 0.d0, c, h, inout)
+               if(nc .eq. 0) then
+                  nc = 1
+                  el1 =  el
+               else
+                  el = min(el1, el)
+                  cond = 1
+                  goto 10
+               endif
+            endif
+c        else
+c           not coming here 
+         endif
+         cond = -1
+      endif
+ 10   continue
+      end
