@@ -7,7 +7,11 @@
 
       real*8 Et
       integer ia, iz
-
+!///////////
+!      integer ns
+!      record /epTrack/temp
+!      integer,save:: nelec=0
+!////////////
       if( Move.proc .eq. 'pair' ) then
          call epmuPrsmpE(Media(MediaNo), Move.Track.p.fm.p(4),
      *                   Et)
@@ -21,6 +25,18 @@ c              to do so, make cTrack a gamma of energy Et
             call cmkptc(kphoton, 0, 0, cTrack.p)
             call epe2p(cTrack)       ! this may not be needed ; for safety
             call eppair
+!/////////////////
+!            nelec = nelec +1
+!            call epqstn(ns)
+!            call epqsTrack(ns, temp)
+!            write(*,'(a, 2i3,i5, 1p,g15.4)') 'mpair',  nelec,
+!     *       temp.p.code, temp.p.charge, temp.p.fm.p(4)
+!            ns = ns -1
+!            call epqsTrack(ns, temp)
+!            nelec = nelec +1
+!            write(*,'(a, 2i3,i5, 1p,g15.4)') 'mpair',  nelec,
+!     *       temp.p.code, temp.p.charge, temp.p.fm.p(4)
+!////////////////
 c           &&&&&9.06
          elseif( Media(MediaNo).mu.MuPr .eq. 2) then
             Move.dE=Et
@@ -66,6 +82,7 @@ c                 for small basic cross section case.
                call epfixTarget2(ActiveMdl, Media(MediaNo))
                call ep2cosCond2(Media(MediaNo).colA, 
      *                          Media(MediaNo).colZ)
+               call cfixModel( cTrack.p )  ! reset model since E<mu's
                call cphotop     ! Cosmos function
                call eppushPtcl(cTrack) ! use pos. info from this ptcl
 c                 &&&&&9.06
