@@ -406,17 +406,23 @@ c
       record /epPos/ p2  ! input. second point
       record /epPos/ p3  ! input. 3rd point.  They should not be on a line.
       record /epPos/ n   ! output.a vector normal to the plane  formed by
-                         !      p1,p2,p3.
+                         !      p1,p2,p3.. it is a unit vector (from v9.136) 
       real*8 k           ! output. const to represent the plane.
                          ! vec(n).vec(x) = k where x is any point on the plane.
 
       record /epPos/ p2p1, p3p2
       record /epPos/ p3p1
+      real(8):: norm
       call epdiff3vec(p2, p1, p2p1)
 c      call epdiff3vec(p3, p2, p3p2)
       call epdiff3vec(p3, p1, p3p1)
 c      call epvectorProd(p2p1, p3p2, n)
       call epvectorProd(p2p1, p3p1, n)
+      call epscalerProd(n, n, norm)
+      norm = sqrt(norm)
+      n.x = n.x/norm
+      n.y = n.y/norm
+      n.z = n.z/norm
       call epscalerProd(n, p1, k)
       end
       
