@@ -17,15 +17,21 @@ c                          from posl with dirl
 c                       0-->length obtained. pos  is  inside 
 c                       1-->length obtained. pos  is  outside
 c                      -1-->not cross 
-
+c 
+      integer uscl
 c           compute the minimum length to the boundary
-      if(comp.struc(1:8) .eq. 'cap') then
-         call epbcap(comp, posl, dirl,  length, icon)
-      elseif(comp.struc(1:8) .eq. 'ellips') then
-         call epbellips(comp, posl, dirl, length, icon)
-      elseif(comp.struc(1:8) .eq. 'angle') then
-         call epbangle(comp, posl, dirl, length, icon)
-c---  elseif(comp.struc(1:8) .eq. '%2') then
+      call epseeUnderScore(comp.struc, uscl)
+      if(comp.struc(1:uscl) .eq. 'ocyl') then
+         call epbocyl(comp, posl, dirl,  length, icon)
+      elseif(comp.struc(1:uscl) .eq. 'octagon') then
+         call epboctagon(comp, posl, dirl, length, icon)
+      elseif(comp.struc(1:uscl) .eq. 'horse') then
+         call epbhorse(comp, posl, dirl, length, icon)
+      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
+         call epboecyl(comp, posl, dirl, length, icon)
+      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
+         call epbhoneycomb(comp, posl, dirl, length, icon)
+c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epb%2(comp, posl, dirl,  length, icon)
       else
          call cerrorMsg(comp.struc(1:8), 1)
@@ -47,16 +53,23 @@ c             see if pos is inside the comp component
       record /epPos/pos  ! input. given point
       integer icon  !   output.  0-->inside. 1-->outside
 
-      if(comp.struc(1:8) .eq. 'cap')  then
-         call epscap(comp, pos, icon)
-      elseif(comp.struc(1:8) .eq. 'ellips') then
-         call epsellips(comp, pos, icon)
-      elseif(comp.struc(1:8) .eq. 'angle') then
-         call epsangle(comp, pos, icon)
-c---  elseif(comp.struc(1:8) .eq. '%2')  then
+      integer uscl
+
+      call epseeUnderScore(comp.struc, uscl)
+      if(comp.struc(1:uscl) .eq. 'ocyl')  then
+         call epsocyl(comp, pos, icon)
+      elseif(comp.struc(1:uscl) .eq. 'octagon') then
+         call epsoctagon(comp, pos, icon)
+      elseif(comp.struc(1:uscl) .eq. 'horse') then
+         call epshorse(comp, pos, icon)
+      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
+         call epsoecyl(comp, pos, icon)
+      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
+         call epshoneycomb(comp, pos, icon)
+c---  elseif(comp.struc(1:uscl) .eq. '%2')  then
 c---     call eps%2(comp, pos, icon)
       else
-         call cerrorMsg(comp.struc(1:8), 1)
+         call cerrorMsg(trim(comp.struc), 1)
          call cerrorMsg(' is not supported: epsNew', 0)
       endif
          
@@ -71,17 +84,22 @@ c     ***********************************
 
       character*(*)  shape     ! input.  config data has this shape
 c            read configuration data 
-
-      if(shape(1:8)  .eq. 'cap') then
-         call eprcap(comp)
-      elseif(shape(1:8) .eq. 'ellips') then
-         call eprellips(comp)
-      elseif(shape(1:8) .eq. 'angle') then
-         call eprangle(comp)
-c---  elseif(shape(1:8)  .eq. '%2') then
+      integer uscl
+      call epseeUnderScore(shape, uscl)
+      if(shape(1:uscl)  .eq. 'ocyl') then
+         call eprocyl(comp)
+      elseif(shape(1:uscl) .eq. 'octagon') then
+         call eproctagon(comp)
+      elseif(shape(1:uscl) .eq. 'horse') then
+         call eprhorse(comp)
+      elseif(shape(1:uscl) .eq. 'oecyl') then
+         call eproecyl(comp)
+      elseif(shape(1:uscl) .eq. 'honeycomb') then
+         call eprhoneycomb(comp)
+c---  elseif(shape(1:uscl)  .eq. '%2') then
 c---     call epr%2(comp)
       else
-         call cerrorMsg(shape(1:8), 1)
+         call cerrorMsg(trim(shape), 1)
          call cerrorMsg(' is not supported: eprNew ', 0)
       endif
 
@@ -99,14 +117,21 @@ c
       record /Component/ comp  ! input. given component
       record /epPos/ orig      ! output. origin
       record /ep3Vec/ abc      ! output. a,b,c of the box.
+      integer uscl
 
-      if(comp.struc(1:8) .eq. 'cap') then
-         call epenvlpcap(comp, orig, abc)
-      elseif(comp.struc(1:8) .eq. 'ellips') then
-         call epenvlpellips(comp, orig, abc)
-      elseif(comp.struc(1:8) .eq. 'angle') then
-         call epenvlpangle(comp, orig, abc)
-c---  elseif(comp.struc(1:8) .eq. '%2') then
+      call epseeUnderScore(comp.struc, uscl)
+
+      if(comp.struc(1:uscl) .eq. 'ocyl') then
+         call epenvlpocyl(comp, orig, abc)
+      elseif(comp.struc(1:uscl) .eq. 'octagon') then
+         call epenvlpoctagon(comp, orig, abc)
+      elseif(comp.struc(1:uscl) .eq. 'horse') then
+         call epenvlphorse(comp, orig, abc)
+      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
+         call epenvlpoecyl(comp, orig, abc)
+      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
+         call epenvlphoneycomb(comp, orig, abc)
+c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epenvlp%2(comp, orig, abc)
       else
          call cerrorMsg(comp.struc(1:8), 1)
@@ -126,16 +151,24 @@ c
                          !  the config file. It's value is in 
                          !  Volat( comp.vol + loc(i)).
                          !  loc size must be >= comp.Nattributes
-      if(comp.struc(1:8) .eq. 'cap') then
-         call epatloccap(comp, loc)
-      elseif(comp.struc(1:8) .eq. 'ellips') then
-         call epatlocellips(comp, loc)
-      elseif(comp.struc(1:8) .eq. 'angle') then
-         call epatlocangle(comp, loc)
-c---  elseif(comp.struc(1:8) .eq. '%2') then
+      integer uscl
+
+      call epseeUnderScore(comp.struc, uscl)
+
+      if(comp.struc(1:uscl) .eq. 'ocyl') then
+         call epatlococyl(comp, loc)
+      elseif(comp.struc(1:uscl) .eq. 'octagon') then
+         call epatlococtagon(comp, loc)
+      elseif(comp.struc(1:uscl) .eq. 'horse') then
+         call epatlochorse(comp, loc)
+      elseif(comp.struc(1:uscl) .eq. 'oecyl') then
+         call epatlocoecyl(comp, loc)
+      elseif(comp.struc(1:uscl) .eq. 'honeycomb') then
+         call epatlochoneycomb(comp, loc)
+c---  elseif(comp.struc(1:uscl) .eq. '%2') then
 c---     call epatloc%2(comp, loc)
       else
-         call cerrorMsg(comp.struc(1:8), 1)
+         call cerrorMsg(comp.struc, 1)
          call cerrorMsg(' is not supported: epatlocNew', 0)
       endif
       end
