@@ -24,9 +24,8 @@ c
       integer i, cnxx, j, cnx, jcon
       record /epPos/postemp
       record /epDirec/ dirtemp
-
-
 c          present comp, boundary
+
       call epbndry2(Cn, el, jcon)
       if(jcon .ne. 0) then
 c               No boundary found in the  present comp. strange.
@@ -36,7 +35,6 @@ c         etc and continue the execution.
 c         However, this also happens if a wrong incident direcion is given,
 c         too or by some unkown reason. So we count the occurence / event
 c         issue messages.
-
          Bndryerr = Bndryerr + 1    ! count it
          call eppos2cn(Cn, cTrack, cnxx)
          if(cnxx .ge. Det.nct) then
@@ -55,31 +53,39 @@ c         issue messages.
          call cerrorMsg(
      *    'component boundary might have buffalloed Epics.' , 1) 
          call cerrorMsg(
-     *    'Epics tries to recover the matter safely.', 1)
+     *    'Epics is expected to recover the matter safely.', 1)
          call cerrorMsg(
      *    'However, some unknown cause may lead to this, ', 1)
          call cerrorMsg(
      *    'so check the coordinate below, if they are very ',1)
          call cerrorMsg(
-     *    'near to the boundary, it may be ok', 1)
-         write(msg, *) ' Cn for current pos=',Cn,
-     *           ' which should be ', cnxx
+     *    'near to the boundary, it will  be ok', 1)
+         write(msg, *) ' Cn for current pos=',Cn, ' name=',
+     *     Det.cmp(Cn).struc, ' which should be ', cnxx, ' ',
+     *     Det.cmp(cnxx).struc
          call cerrorMsg(msg, 1)
-         write(msg,*) ' x y z=', cTrack.pos.x, cTrack.pos.y,
+         write(msg,*) 'local x y z=', cTrack.pos.x, cTrack.pos.y,
      *        cTrack.pos.z
          call cerrorMsg(msg, 1)
-         write(msg,*) 'Move.Track.pos =', Move.Track.pos.x,
+         write(msg,*) 'local Move.Track.pos =', Move.Track.pos.x,
      *        Move.Track.pos.y, Move.Track.pos.z
          call cerrorMsg(msg, 1)
-         write(msg,*) 'cTrack wx.y,z=',cTrack.w.x,
+         write(msg,*) 'local cTrack wx.y,z=',cTrack.w.x,
      *        cTrack.w.y, cTrack.w.z
          call cerrorMsg(msg, 1)
-         write(msg,*) ' cTrack E=',cTrack.p.fm.p(4), ' Move E=',
+         write(msg,*) 'NOTE: local above means local coordinate'
+         call cerrorMsg(msg, 1)
+         write(msg,*) '  so  if component name has "_", it is different'
+         call cerrorMsg(msg, 1)
+         write(msg,*) '  from  canonical coordinate'
+         call cerrorMsg(msg, 1)
+         write(msg,*) ' cTrack T.E=',cTrack.p.fm.p(4), ' Move TE=',
      *        Move.Track.p.fm.p(4),  ' code=',cTrack.p.code,
      *      ' subcode=', cTrack.p.subcode,' chg=',cTrack.p.charge
          call cerrorMsg(msg,1)
          call cerrorMsg('-------------------------------',1)
-         if( Bndryerr  .gt. 100 ) then
+         if( Bndryerr  .gt. 
+     *       max(int(10*Total1ryE/100), 10) ) then
             call cerrorMsg('too many boundary error', 0)
          endif
          if(Cn .ne. cnxx) then
@@ -134,60 +140,3 @@ c))))))))))
          icon = 0
       endif
       end
-      subroutine epbndry2(cnx, el, icon)
-       implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-c
-c          get the length to the nearest crossing point of cTrack
-c          and the specified component
-c
-        integer cnx   ! input. cnx-th component is examined
-        real*8  el    ! output. length to the boundary of the cnx-th  comp
-                      !         from cTrack.
-        integer icon  ! output. 0, x,y,z is inside
-                      !         1  outside,
-                      !        -1  no Xssing
-
-        record /epPos/ posw, posl
-        record /epDirec/ dirw, dirl
-
-
-        character*80 msg
-        character*8  epparaphrase, tempph
-
-        if(Cn .eq. cnx) then
-c            no need to conv. to local.coor.
-           posl =cTrack.pos
-           dirl =cTrack.w 
-        else
-           call epl2w(Cn, cTrack.pos, posw)
-           call epw2l(cnx, posw, posl)
-           call epl2wd(Cn, cTrack.w, dirw)
-           call epw2ld(cnx, dirw, dirl)
-        endif
-
-        if(Det.cmp(cnx).struc(1:3) .eq. 'box') then
-           call epbbox(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:3) .eq. 'cyl') then
-           call epbcyl(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:4) .eq. 'pipe') then
-           call epbpip(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:5) .eq. 'prism') then
-           call epbprs(Det.cmp(cnx), posl, dirl,  el, icon)
-        elseif(Det.cmp(cnx).struc(1:6) .eq. 'sphere') then
-           call epbsph(Det.cmp(cnx), posl, dirl, el, icon)
-        elseif(Det.cmp(cnx).struc(1:4) .eq. 'new-') then
-           call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
-        else
-           tempph = epparaphrase(Det.cmp(cnx).struc(1:8))
-           if(tempph(1:4) .eq. 'new-') then
-              call epbNew(Det.cmp(cnx), posl, dirl, el, icon)
-           else
-c                   
-              write(msg, *) ' strange structure=',
-     *             Det.cmp(cnx).struc
-              call cerrorMsg(msg, 0)
-           endif
-        endif
-        end
