@@ -10,7 +10,7 @@ c        *********************************************************
 c
       module moddedx
 c         work common block for dedx (GeV/g/cm2) (epEloss / epchcke)
-      real(8):: dedx  !  restricted dE/dx
+      real(8):: dedx  !  restricted dE/dx 
       real(8):: dedxf  ! full dE/dx
       end module moddedx
 
@@ -151,7 +151,7 @@ c<<<<<<<<<<<<<<
           Efield.z = Ezu
        endif
 c
-c          fix tracedir 
+c          fix tracedir ; This must be before uiaev in future
        if(Trace) then
           if(TraceDir .eq. ' ') then
              call cgetLoginN(uid) ! cosmos function
@@ -166,6 +166,7 @@ c             init for 1 event
 #include "ZepManager.h"
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
+
        integer icon ! output. if  0,  user has set ptcl in stack
                    !             1,  no ptcl has set in stack
       character*200 msg
@@ -175,6 +176,11 @@ c             init for 1 event
       integer  klena, i
 
        Bndryerr = 0   ! counter for bundary search failures/ event
+       Making1ry = 1  ! Now preparing 1 event so 1ry is being made
+                    ! will be made to be 0 at epr1ev.
+                    ! If this is 1, partcles being stacked are 1ry
+                    ! we counts total energy of 1ry.
+       Total1ryE = 0. ! clear total 1ry K.E counter of the current event
        Cn=-1
        Firsti=.true.
        FirstC=.true.
@@ -280,6 +286,7 @@ c           call cerrorMsg('no incident found in epr1ev', 0)
 c        endif
 c
         call uafi1ev            ! after init of 1 event
+        Making1ry = 0        
         end
 c      ****************************
 c                user dependent all event end
@@ -335,7 +342,7 @@ c          add  time
 
 c           adjust momentum; because of  energy change
          if(cTrack.p.charge .ne. 0) then
-            call epe2p(Move.Track.p)
+            call epe2p(Move.Track)  ! not Move.Track.p; bug <=v9.13
          endif
 
 c            if(.not. Move.Cross .and. cTrack.p.charge .ne. 0) then
@@ -744,9 +751,8 @@ c     **********************
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
 #include "Zcode.h"
-c////////////////                                                              
-c      logical show
-c      common /showshow/ show
+c////////////////
+!      real(8):: pathp, pathb, pathn  
 c///////////       
       integer jcon
 c          sample interaction length for non-e/g
@@ -781,6 +787,9 @@ c            treate it here.
      *                      cTrack.p.fm.p(4), prob, path)
 c               path is in r.l. convert  it to kg/m2
             path = path * tokgpm2 
+c//////////////
+c            pathp = path
+c/////////////
             call csetIntInf(path, .false., 'pair')
          endif
          if(Media(MediaNo).mu.MuBr  .ge. 2 .and.
@@ -790,6 +799,9 @@ c               path is in r.l. convert  it to kg/m2
 c               path is in r.l. convert  it to kg/m2
             path = path*tokgpm2
             call csetIntInf(path, .false., 'brem')
+c//////////////
+c            pathb = path
+c/////////////
          endif
          if( Media(MediaNo).mu.MuNI  .ge. 2 .and.
      *       cTrack.p.fm.p(4) .gt.  Media(MediaNo).cnst.muNEmin ) then
@@ -798,7 +810,13 @@ c               path is in r.l. convert  it to kg/m2
 c               path is in r.l. convert  it to kg/m2
             path = path*tokgpm2
             call csetIntInf(path, .false., 'nuci')
+c//////////////
+c            pathn = path
+c/////////////
          endif
+c////////////////
+c         write(*, '(a, 1p, 3g15.4)') 'muon', pathp, pathb, pathn
+c//////////
       endif
 
       call epfixProc(Media(MediaNo).rho*Media(MediaNo).rhoc,
@@ -831,6 +849,8 @@ c     ******************
       real*8  dx, up, dedxmu, dedlmu,
      *      s1, s2, scol2, schg2, sigma
       real*8 cupsilon, csyncTELoss, cf
+      real(8):: dEdxbyBrems, dEdxbyBremsf
+      real(8):: dEdlBrems
       logical lowehvyion
       real(8),save::  dedl
       real(8):: dedxout, dedlout
@@ -841,6 +861,9 @@ c     ******************
       k = cTrack.p.code
 c              compute energy loss rate
       if(EdepdEdx) then
+         dEdxbyBrems = 0.
+         dEdxbyBremsf = 0.
+         dEdlBrems = 0.
          lowehvyion  = .false.
          if(cTrack.p.fm.p(4) .le. cTrack.p.mass) then
             dedx = 0.
@@ -869,6 +892,8 @@ c                            dedx is in GeV/(g/cm^2)
                   call epdedxhvy(Media(MediaNo), cTrack.p, dedx,dedxf)
                else
                   call epdedxNone(Media(MediaNo), cTrack.p, dedx,dedxf)
+                  call epdedxTargetBrems(Media(MediaNo), cTrack.p, 
+     *               dEdxbyBrems, dEdxbyBremsf)
                endif
                if(cTrack.p.code .eq. kmuon) then
                   call epmudEdx(Media(MediaNo).mu.MuNI, 
@@ -889,7 +914,7 @@ c            if( cTrack.p.charge >= 1) then ! ????
                if( modif > 0 .or.  Media(MediaNo).Birks /= ' ') then
 c                even if no quenching is specified in media file,
 c                modifier can  force quenching. inside of the next,
-c                kind is checed if really quenching is specified by modifier
+c                kind is checked if really quenching is specified by modifier
                   call epOrgCorrec( modif,
      *              Media(MediaNo), cTrack.p, dedx, cf)
                else
@@ -903,6 +928,16 @@ c                kind is checed if really quenching is specified by modifier
      *         Media(MediaNo).rhoc
             dedlmu = dedxmu /Media(MediaNo).gtocm * ! GeV/cm
      *         Media(MediaNo).rhoc
+            if( btest(TargetElecBrems, 2)) then
+!                         this will overestimate for thin media
+               dEdlBrems = dEdxbyBremsf/Media(MediaNo).gtocm * 
+     *         Media(MediaNo).rhoc   
+            elseif( btest(TargetElecBrems, 0) .or.
+     *           btest(TargetElecBrems, 1)  ) then
+!                     this will underestimate
+               dEdlBrems = dEdxbyBrems/Media(MediaNo).gtocm * 
+     *         Media(MediaNo).rhoc   
+            endif
             if( abs( epLightGetd( Det.cmp(Cn).CountDE) ) .eq. 2) then
 c                Enery loss fluctuation; use  Urban model for singl charge
 c                 or  high energy
@@ -920,11 +955,13 @@ c                    Move.dEioni = GeV  in 'dl' cm
             else
                Move.dEioni = dedl * Move.dl
             endif
-            Move.dE = Move.dEioni + dedlmu*Move.dl  ! total loss
-            Move.dEeff = Move.dEioni * cf + dedlmu*Move.dl  ! effective loss
+            Move.dE = Move.dEioni + dedlmu*Move.dl  
+     *            + dEdlBrems*Move.dl  ! total loss without quenching
+            Move.dEeff = Move.dEioni * cf + dedlmu*Move.dl  
+     *            + dEdlBrems*Move.dl   ! effective loss with quenching
          endif
       else
-c            use constant energy loss at minimum ionization
+c            use constant energy loss at minimum ionization; actually not used
 c            In this case, knock-on process should be prohibitted  by
 c            giving large Tcut.   Birks etc correction not applied.
          dedx = Media(MediaNo).dEdxatp3m * cTrack.p.charge**2  ! GeV/(g/cm2)
@@ -1102,6 +1139,7 @@ c
 #include  "ZepTrackv.h"
 #include  "ZepTrackp.h"
 
+
 c
       real*8 tcomp, tphot, tpair, tgp, tcoh,  t
       real*8 E, prob, xprob(5), txray(5)
@@ -1156,7 +1194,7 @@ c               below 1MeV, use accurate xs.
       else
          tpair=1.e35
       endif
-      if(IncGp > 0 .and. E .gt. 152.d-3) then
+      if(IncGp > 0 .and. E .gt. 153.d-3) then ! > 0.152431798977028
          call ep2cosCond
          call cfixModel( cTrack.p )
          call cgpXsec(Media(MediaNo).A,  E, xs)    ! xs in mb
