@@ -65,7 +65,12 @@ c
       if(media.sumns /= smallxs .and. media.sumns /= largexs) then
 c           prop to rhoc so next two are indep. of rhoc
          xs = media.sumns/media.nd ! mb/cm3 /(1/cm3)
-         mfp = 10.*media.rho/(media.sumns*mbTocm2)   ! in kg/m2. Not in g/cm2
+         if( xs <= 0. ) then
+            xs = smallxs
+            mfp = largexs
+         else
+            mfp = 10.*media.rho/(media.sumns*mbTocm2) ! in kg/m2. Not in g/cm2
+         endif
                                           ! to be consistent with other  part.
 c/////////////
 c         if( pj.code == knuc) then
@@ -88,7 +93,8 @@ c////////////
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zmedia.h"
-#include "ZepTrackp.h"
+!#include "ZepTrackp.h"
+#include "Ztrackp.h"
 #include "Zevhnp.h"
       record /ptcl/ pj  ! input ptcl
       record /epmedia/ media    ! input/output
