@@ -43,20 +43,68 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, EminElec)
                elseif( vname .eq. 'EminGamma') then
                   call arprmr(vvalue, EminGamma)
+               elseif( vname .eq. 'AutoEmin') then
+                  call arprmi(vvalue, AutoEmin)
+               elseif( vname .eq. 'ModifyFile') then
+                  call arprmc(vvalue, ModifyFile)
                elseif( vname .eq. 'EminH') then
                   call arprmr(vvalue, EminH)
                elseif( vname .eq. 'Es' ) then
                   call arprmr(vvalue, Escat)
-               elseif( vname .eq. 'EupperBndCS ') then
+               elseif( vname .eq. 'EupperBndCS') then
                   call arprmr(vvalue, EupperBndCS)
+               elseif( vname .eq. 'EpartialSC') then
+                  call arprmr(vvalue, EpartialSC)
+                  if( EpartialSC < 0.1d0 .or.
+     *                EpartialSC > 10.d0 ) then
+                     write(0,*) 'EpartialSC=',EpartialSC
+                     write(0,*) ' invalid in epicsfiel'
+                     write(0,*) ' must be 0.1~10 '
+                     stop
+                  endif        
+               elseif( vname == 'TargetElecBrems' ) then
+                  call arprmi(vvalue, TargetElecBrems)
+                  if( TargetElecBrems < 0 .or. TargetElecBrems >7 ) then
+                     write(0,*) 'TargetElecBrems=',TargetElecBrems,
+     *                 ' invalid'
+                     stop
+                  endif
+               elseif( vname .eq. 'Flpm') then
+                  call arprmr(vvalue, Flpm)
+                  if( Flpm < 1.0 ) then
+                     write(0,*) 'Flpm=',Flpm, ' invalid'
+                     write(0,*) 'must be >= 1 (<500)'
+                     stop
+                  elseif( Flpm > 500.) then
+                     write(0,*) 'Flpm=',Flpm, ' too large'
+                     write(0,*) ' normal range is 1~100'
+                     write(0,*) '======================'
+                     write(0,*) '======================'
+                     write(0,*) 
+     *               ' ***** Experimental purpose ?****'
+                     write(0,*) '======================'
+                     write(0,*) '======================'
+                  endif
+               elseif( vname .eq. 'HowNormBrems') then
+                  call arprmi(vvalue, HowNormBrems)
                elseif( vname .eq. 'IncGp') then
-                  call arprmi(vvalue, IncGp)
+                  write(0,*) 'Sorry: IncGp is managed by param file'
+                  write(0,*) 
+     *       'If needed, use HowPhotoP(D=4)in &HPARAM part of param'
+                  stop
                elseif( vname .eq. 'IoTrace') then
                   call arprmi(vvalue, IoTrace)
                elseif( vname .eq. 'Knckon' ) then
                   call arprml(vvalue, Knckon)
                elseif( vname .eq. 'Molier' ) then
-                  call arprml(vvalue, Moliere)
+                  call arprmc(vvalue, msg)
+                  if( msg == 't' .or. msg == 'T') then
+                     Moliere = 1
+                  elseif( msg == 'f' .or. msg == 'F' ) then
+                     Moliere = 0
+                  else
+                     call arprmi(vvalue, Moliere)
+                  endif
                elseif( vname .eq. 'Photo') then
                   call arprml(vvalue, Photo)
                elseif( vname .eq. 'RecoilKeMin') then
@@ -127,6 +175,19 @@ c            read baisc parameters; find separater
                   call arprmr(vvalue, Excom2) 
                elseif( vname .eq. 'LPMeffect' ) then
                   call arprml(vvalue, LPMeffect)                 
+               elseif( vname == "StoppingPw" ) then
+                  call arprmi(vvalue, StoppingPw)
+               elseif( vname == "SrimEmax" ) then
+                  call arprmr(vvalue, SrimEmax)
+               elseif( vname == "PhitsXs" ) then
+                  write(0,*) 'PhitsXs is not used now'
+                  write(0,*) 'Please drop it from epicsfile'
+                  stop
+               elseif( vname == "JamXs" ) then
+                  write(0,*) 'Sorry: JamXs is managed by param file'
+                  write(0,*) 
+     *       'If needed, put it(D=0) in &HPARAM part of param'
+                  stop
                else
                   write(0,*) ' epicsfile parameter: ', vname,
      *                 ' is undefined '
@@ -154,13 +215,19 @@ c      *************
             call awprmr(io,'ElowerBndPair ', ElowerBndPair)
             call awprmr(io,'EminElec', EminElec)
             call awprmr(io,'EminGamma', EminGamma)
+            call awprmi(io,'AutoEmin', AutoEmin)
+            call awprmc(io, 'ModifyFile', ModifyFile)
             call awprmr(io,'EminH', EminH)
             call awprmr(io,'Es   ', Escat)
             call awprmr(io,'EupperBndCS ', EupperBndCS)
-            call awprmi(io,'IncGp', IncGp)
+            call awprmr(io,'EpartialSC ', EpartialSC)
+            call awprmi(io,'TargetElecBrems', TargetElecBrems)
+            call awprmr(io,'Flpm ', Flpm)
+            call awprmi(io,'HowNormBrems', HowNormBrems)
+!            call awprmi(io,'IncGp', IncGp)
             call awprmi(io,'IoTrace', IoTrace)
             call awprml(io,'Knckon', Knckon)
-            call awprml(io,'Molier', Moliere)
+            call awprmi(io,'Molier', Moliere)
             call awprml(io,'Photo', Photo)
             call awprmr(io,'RecoilKeMin', RecoilKEmin)
             call awprmr(io,'Tcoef' , Tcoef)
@@ -181,6 +248,9 @@ c      *************
             call awprmr(io, 'Excom1', Excom1)
             call awprmr(io, 'Excom2', Excom2)
             call awprml(io, 'LPMeffect', LPMeffect)
+            call awprmi(io, 'StoppingPw', StoppingPw)
+!            call awprmi(io, 'PhitsXs', PhitsXs)
+!            call awprmi(io, 'JamXx', JamXs)
             do i = 1, MaxMediaDir
                call awprmc(io, 'MediaDir', MediaDir(i))
             enddo
@@ -190,14 +260,16 @@ c      *************
 c      ************
        subroutine  epcmp1
 c      ************
+       use epModify
        implicit none
 #include "ZepTrackp.h"
 #include "ZepTrackv.h"
+#include "ZepManager.h"
 #include "Zmass.h"
 c             compute something using basic parameters
 c
        if(ALateCor .eq. 2 .or.
-     *        ( ALateCor .eq. 1 .and. .not. Moliere)) then
+     *        ( ALateCor .eq. 1 .and.  Moliere == 0)) then
 c          angular latelaral correlation will be taken at
 c          multiple scattering. use standard trucation
           Tcoefx = Tcoef
@@ -209,12 +281,28 @@ c          truncation length shorter
           Tminx = Tmin/2
        endif
        if(KEmin .eq. 0.) then
-          KEmin = EminElec - masele
+          KEmin = max(EminElec - masele, 20.d-3)  ! 20 MeV
        endif
        if( EminH == 0. ) then
-          EminH = max( KEmin, 5.d-3) 
+          EminH = max( KEmin, 20.d-3)   ! for nutron
        endif
        if( RecoilKEmin .eq. 0.) then
           RecoilKEmin =EminElec - masele
        endif
+c           save;  to be used in epModify;  in GeV
+       EminGsave = EminGamma
+       EminEsave = EminElec
+       RecoilEsave = RecoilKEmin
+       KEminsave = KEmin 
+       Enminsave = EminH 
+       ElecMass = masele  
+
+
+       if( ModifyFile /= " " ) then  ! special modification requested
+          call epfixModifier(ModifyFile)
+       endif
+c        get info from  Cosmos
+       call epInfoPhotoP( IncGp )
+! 
+!       call epInfoPhitsJamXs( PhitsXs, JamXs )
        end
