@@ -21,20 +21,20 @@ c
 
        character*70 msg
 c
-       if(form .eq. 'box') then
-c                   only boxes with the same a, b 
-          call epsbox(ncx, aTrack, nc)
-       elseif(form .eq. 'cyl') then
-          call epscyl(ncx, aTrack, nc)
-       elseif(form .eq. 'pipe') then
-          call epspip(ncx, aTrack, nc)
-       elseif(form .eq.  'mix') then
+!!       if(form .eq. 'box') then
+!!c                   only boxes with the same a, b 
+!!          call epsbox(ncx, aTrack, nc)
+!!       elseif(form .eq. 'cyl') then
+!!          call epscyl(ncx, aTrack, nc)
+!!       elseif(form .eq. 'pipe') then
+!!          call epspip(ncx, aTrack, nc)
+!!       elseif(form .eq.  'mix') then
           call epsall(ncx, aTrack.pos,  nc)
-       else
-          write(msg,*)
-     *         ' eppos2cn for form=',form, ' not supported'
-          call cerrorMsg(msg, 0)
-       endif
+!       else
+!          write(msg,*)
+!     *         ' eppos2cn for form=',form, ' not supported'
+!          call cerrorMsg(msg, 0)
+!       endif
       end
       subroutine epsInside(pos, nci,  nco)
       implicit none
@@ -94,7 +94,8 @@ c
       character*8  epparaphrase, tempph
 
       integer  ncx,  i, icon
-c
+      integer uscl
+c     
       i = ncx
 
       if(Det.cmp(i).struc(1:3) .eq. 'box') then
@@ -109,17 +110,19 @@ c
       elseif(Det.cmp(i).struc(1:6) .eq. 'sphere') then
          call epsssph(i, pos, icon)
 
-      elseif(Det.cmp(i).struc(1:5) .eq. 'prism') then   
+      elseif(Det.cmp(i).struc .eq. 'prism' .or.
+     *      Det.cmp(i).struc(1:6) .eq. 'prism_') then   
          call epsprism(i, pos, icon)
       elseif(Det.cmp(i).struc(1:4) .eq. 'new-') then
          call epsNew(Det.cmp(i), pos, icon)
       else
-         tempph = epparaphrase(Det.cmp(i).struc(1:8))
+         call epseeUnderScore(Det.cmp(i).struc, uscl)
+         tempph = epparaphrase(Det.cmp(i).struc(1:uscl))
          if(tempph(1:4) .eq. 'new-') then
             call epsNew(Det.cmp(i), pos, icon)
          else
-            write(msg, *) ' struc=', Det.cmp(i).struc,'  for ',i,
-     *           '-th comp. invalid'
+            write(msg, *) ' struc=', trim(Det.cmp(i).struc),
+     *           '  for ',i,'-th comp. invalid'
             call cerrorMsg(msg, 0)
          endif
       endif
@@ -173,12 +176,13 @@ c))))))))))
                call epspip1(ii, posl, icon)
             elseif(Det.cmp(ii).struc(1:6) .eq. 'sphere') then
                call epsssph(ii, posl, icon)
-            elseif(Det.cmp(ii).struc(1:5) .eq. 'prism') then
+            elseif(Det.cmp(ii).struc .eq. 'prism' .or.
+     *             Det.cmp(ii).struc(1:6) .eq. 'prism_') then
                call epsprism(ii, posl,  icon)
             elseif(Det.cmp(ii).struc(1:4) .eq. 'new-') then
                call epsNew(Det.cmp(ii),  posl, icon)
             else
-               tempph = epparaphrase(Det.cmp(ii).struc(1:8))
+               tempph = epparaphrase(Det.cmp(ii).struc)
                if(tempph(1:4) .eq. 'new-') then
                   call epsNew(Det.cmp(ii),  posl, icon)
                else
@@ -297,25 +301,33 @@ c                pos into posw
 c                 -----------------
 c       search other comp.  for the fast search, 
 c       first examine uncontained component  only.
-      do i = ncx+1,  Det.nct
+!!!!!!! v9.14 except for small detectors consisting of same
+!             area, only the world is uncontained, so
+!             we may search from the last one
+!      do i = ncx+1,  Det.nct
+      do i =  Det.nct, 1, -1
 c         if( (Det.cmp(i).struc(1:3) .eq. 'box'  .or.
 c     *        Det.cmp(i).struc .eq. 'sphere_w')  
 c     *     .and.
 c     *        Det.cmp(i).NContainer .eq. 0) then
+         !!!!!!!!v9.14 only world is with NContainer= 0
+         !!!! so skip non-world comp. 
+         if( i < Det.nct .and. Det.nworld == 1 ) then
+            nc= Det.nct+1
+            goto 10
+         endif
+         !!!!!!!!
          if(Det.cmp(i).NContainer .eq. 0) then
             call epw2l(i, posw, posl)
             call epsOne(i, posl, icon)
 c///////////////
 c            call debugpos('eppos2cn;epsOne', i, posl,icon)
 c//////////////////
-
             if(icon .eq.  0) then
                call epsMatreska(i, posl, nc)
 c///////////////
 c             call debugpos('eppos2cn;epsOne;matre', i, posl,icon)
 c//////////////////
-
-
                if(nc .ne. i) then
                   call epw2l(nc, posw, posl)
                endif
@@ -323,41 +335,6 @@ c//////////////////
 c///////////////
 c            call debugpos('eppos2cn;epsOne;PCont', nc, posl,jcon)
 c//////////////////
-
-               if(jcon .ne. 0) then
-                  nc = Det.nct + 1
-               endif
-               goto 10
-            endif
-         endif
-      enddo
-      do i = ncx -1, 1, -1
-c         if( (Det.cmp(i).struc(1:3) .eq. 'box'  .or.
-c     *        Det.cmp(i).struc .eq. 'sphere_w')  
-c     *     .and.
-c     *        Det.cmp(i).NContainer .eq. 0) then
-         if(Det.cmp(i).NContainer .eq. 0) then
-
-            call epw2l(i, posw, posl)
-            call epsOne(i, posl, icon)
-c///////////////
-c            call debugpos('eppos2cn;epsOne;inv', i, posl,icon)
-c//////////////////
-
-            if(icon .eq. 0) then
-               call epsMatreska(i, posl, nc)
-c///////////////
-c            call debugpos('eppos2cn;matre;inv', i, posl,nc)
-c//////////////////
-
-               if(i .ne. nc) then
-                  call epw2l(nc, posw, posl)
-               endif
-               call epsPCont(nc, posl, jcon)
-c///////////////
-c            call debugpos('eppos2cn;mPCont;inv', nc, posl, jcon) 
-c//////////////////
-
                if(jcon .ne. 0) then
                   nc = Det.nct + 1
                endif
@@ -365,6 +342,40 @@ c//////////////////
             endif
          endif
       enddo
+!      do i = ncx -1, 1, -1
+!c         if( (Det.cmp(i).struc(1:3) .eq. 'box'  .or.
+!c     *        Det.cmp(i).struc .eq. 'sphere_w')  
+!c     *     .and.
+!c     *        Det.cmp(i).NContainer .eq. 0) then
+!         if(Det.cmp(i).NContainer .eq. 0) then
+!
+!            call epw2l(i, posw, posl)
+!            call epsOne(i, posl, icon)
+!c///////////////
+!c            call debugpos('eppos2cn;epsOne;inv', i, posl,icon)
+!c//////////////////
+!
+!            if(icon .eq. 0) then
+!               call epsMatreska(i, posl, nc)
+!c///////////////
+!c            call debugpos('eppos2cn;matre;inv', i, posl,nc)
+!c//////////////////
+!
+!               if(i .ne. nc) then
+!                  call epw2l(nc, posw, posl)
+!               endif
+!               call epsPCont(nc, posl, jcon)
+!c///////////////
+!c            call debugpos('eppos2cn;mPCont;inv', nc, posl, jcon) 
+!c//////////////////
+!
+!               if(jcon .ne. 0) then
+!                  nc = Det.nct + 1
+!               endif
+!               goto 10
+!            endif
+!         endif
+!      enddo
       nc= Det.nct+1
 
  10   continue
@@ -412,52 +423,62 @@ c
          nc=Det.nct+1
       endif
       end
-c      *****************
-      subroutine epscyl(ncx, aTrack, nc)
-      implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-
-      record /epTrack/ aTrack
-      record /epPos/ pos
-      integer ncx, nc
-
-
-c            ncx=0 --> pos is w.c
-c               else ncx-local
-      pos = aTrack.pos
-      if(ncx .le. 0) then
-         call epscya(pos, nc)
-      elseif(ncx .le. Det.nct) then
-         if(0.d0 .le. pos.z      .and.
-     *        pos.z .le. Volat( Det.cmp(ncx).vol + cylh)) then
-            if(pos.x**2 + pos.y**2 .le.
-     *           Volat( Det.cmp(ncx).vol + cylr)**2) then
-               nc=ncx
-            else
-               nc = Det.nct+1
-            endif
-         else
-            if(aTrack.w.z .gt. 0.) then
-               call epscyu(ncx, pos, nc)
-            else
-               call epscyd(ncx, pos, nc)
-            endif
-         endif
-      else
-         nc = Det.nct+1
-      endif
-      end
+!!c      *****************
+!!      subroutine epscyl(ncx, aTrack, nc)
+!!      implicit none
+!!#include  "ZepTrackv.h"
+!!#include  "Zcnfig.h"
+!!
+!!      record /epTrack/ aTrack
+!!      record /epPos/ pos
+!!      integer ncx, nc
+!!      record /epPos/ post
+!!
+!!c            ncx=0 --> pos is w.c
+!!c               else ncx-local
+!!      post = aTrack.pos
+!!
+!!      if(ncx .le. 0) then
+!!         call epscya(post, nc)
+!!      elseif(ncx .le. Det.nct) then
+!!C&&&&&&&
+!!         call epv2c_cyl(Det.cmp(ncx), post, pos)
+!!c&&&&&
+!!         if(0.d0 .le. pos.z      .and.
+!!     *        pos.z .le. Volat( Det.cmp(ncx).vol + cylh)) then
+!!            if(pos.x**2 + pos.y**2 .le.
+!!     *           Volat( Det.cmp(ncx).vol + cylr)**2) then
+!!               nc=ncx
+!!            else
+!!               nc = Det.nct+1
+!!            endif
+!!         else
+!!            if(aTrack.w.z .gt. 0.) then
+!!               call epscyu(ncx, pos, nc)
+!!            else
+!!               call epscyd(ncx, pos, nc)
+!!            endif
+!!         endif
+!!      else
+!!         nc = Det.nct+1
+!!      endif
+!!      end
 c ******************************* search only ncx-th cyl
-      subroutine epscyl1(ncx, pos, icon)
+      subroutine epscyl1(ncx, posi, icon)
         implicit none
 #include "ZepTrackv.h"
 #include "Zcnfig.h"
 
-        record /epPos/ pos
+        record /epPos/ posi
         integer ncx, icon
+!    &&&&&&&&&&
+        record /epPos/ pos
+
 
 c          pos in local-c.
+c  &&&&         convert to canonial one
+        call epv2c_cyl(Det.cmp(ncx), posi, pos)
+c  &&&&&&
         if(0.d0 .le. pos.z      .and.
      *       pos.z .le. Volat( Det.cmp(ncx).vol + cylh)) then
            if(pos.x**2 + pos.y**2 .le.
@@ -470,45 +491,45 @@ c          pos in local-c.
            icon = 1
         endif
         end
-c ****************************
-       subroutine epspip(ncx, aTrack, nc)
-       implicit none
-#include "ZepTrackv.h"
-#include "Zcnfig.h"
-
-       record /epTrack/ aTrack
-       integer ncx,  nc
-        
-       real*8 temp
-       record /epPos/ pos
-c          ncx =0  --> xx in w.c
-c           else     in l.c
-
-       pos = aTrack.pos
-
-       if(ncx .le. 0) then
-          call epspipa(pos, nc)
-       elseif(ncx .le. Det.nct) then
-          if(0.d0 .le. pos.z      .and.
-     *         pos.z .le. Volat( Det.cmp(ncx).vol + pipeh)) then
-             temp = pos.x**2 + pos.y**2 
-             if( temp .le. Volat( Det.cmp(ncx).vol + pipeor)**2 .and.
-     *          temp .ge. Volat( Det.cmp(ncx).vol + pipeir)**2 ) then
-                nc=ncx
-             else
-                nc = Det.nct+1
-             endif
-          else
-             if(aTrack.w.z .gt. 0.) then
-                call epspipu(ncx, pos, nc)
-             else
-                call epspipd(ncx, pos, nc)
-             endif
-          endif
-       else
-          nc = Det.nct+1
-       endif
-       end
+!!c ****************************
+!!       subroutine epspip(ncx, aTrack, nc)
+!!       implicit none
+!!#include "ZepTrackv.h"
+!!#include "Zcnfig.h"
+!!
+!!       record /epTrack/ aTrack
+!!       integer ncx,  nc
+!!        
+!!       real*8 temp
+!!       record /epPos/ pos
+!!c          ncx =0  --> xx in w.c
+!!c           else     in l.c
+!!
+!!       pos = aTrack.pos
+!!
+!!       if(ncx .le. 0) then
+!!          call epspipa(pos, nc)
+!!       elseif(ncx .le. Det.nct) then
+!!          if(0.d0 .le. pos.z      .and.
+!!     *         pos.z .le. Volat( Det.cmp(ncx).vol + pipeh)) then
+!!             temp = pos.x**2 + pos.y**2 
+!!             if( temp .le. Volat( Det.cmp(ncx).vol + pipeor)**2 .and.
+!!     *          temp .ge. Volat( Det.cmp(ncx).vol + pipeir)**2 ) then
+!!                nc=ncx
+!!             else
+!!                nc = Det.nct+1
+!!             endif
+!!          else
+!!             if(aTrack.w.z .gt. 0.) then
+!!                call epspipu(ncx, pos, nc)
+!!             else
+!!                call epspipd(ncx, pos, nc)
+!!             endif
+!!          endif
+!!       else
+!!          nc = Det.nct+1
+!!       endif
+!!       end
        subroutine epsbxu(ncx, pos, nc)
        implicit none
 c              search upward  when form=box
@@ -603,131 +624,131 @@ c             search downword
         nc = Det.nct+1
  201    continue
        end
-       subroutine epscyu(ncx, pos, nc)
-c            pos in l.c
-       implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-       record /epPos/ pos
-       integer ncx, nc
-       record /epPos/ posw, posl
-       integer i
-
-       call epl2w(ncx, pos, posw)
-       do   i=ncx+1, Det.nct
-          call epw2l(i, posw, posl)
-          if(0.d0 .le. posl.z  .and.
-     *         posl.z .le.  Volat( Det.cmp(i).vol + cylh)) then
-             if(posl.x**2 + posl.y**2 
-     *            .le. Volat( Det.cmp(i).vol + cylr)**2)   then
-                nc=i
-                goto 101
-             else
-                nc = Det.nct+1
-                goto 101
-             endif
-          endif
-       enddo
-       nc = Det.nct+1
- 101   continue
-       end
+!!       subroutine epscyu(ncx, pos, nc)
+!!c            pos in l.c
+!!       implicit none
+!!#include  "ZepTrackv.h"
+!!#include  "Zcnfig.h"
+!!       record /epPos/ pos
+!!       integer ncx, nc
+!!       record /epPos/ posw, posl
+!!       integer i
+!!
+!!       call epl2w(ncx, pos, posw)
+!!       do   i=ncx+1, Det.nct
+!!          call epw2l(i, posw, posl)
+!!          if(0.d0 .le. posl.z  .and.
+!!     *         posl.z .le.  Volat( Det.cmp(i).vol + cylh)) then
+!!             if(posl.x**2 + posl.y**2 
+!!     *            .le. Volat( Det.cmp(i).vol + cylr)**2)   then
+!!                nc=i
+!!                goto 101
+!!             else
+!!                nc = Det.nct+1
+!!                goto 101
+!!             endif
+!!          endif
+!!       enddo
+!!       nc = Det.nct+1
+!! 101   continue
+!!       end
 c
-c       ************
-      subroutine epscyd(ncx, pos, nc)
-c       ************
-c            pos in l.c
-       implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-       record /epPos/ pos
-       integer ncx, nc
-       record /epPos/ posw, posl
-       integer i
-
-c             search downward
-        call epl2w(ncx, pos, posw)
-        do   i=ncx-1, 1, -1
-           call epw2l(i, posw, posl)
-           if(0.d0 .le. posl.z  .and.
-     *              posl.z .le.  Volat( Det.cmp(i).vol + cylh)) then
-              if(posl.x**2 + posl.y**2 
-     *          .le. Volat( Det.cmp(i).vol + cylr)**2)  then
-                 nc=i
-                 goto 201
-              else
-                 nc = Det.nct+1
-                 goto 201
-              endif
-           endif
-        enddo
-        nc = Det.nct+1
- 201    continue
-       end
-c      ***********************************
-       subroutine epspipu(ncx, pos, nc)
-c         pos in l.c
-       implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-       record /epPos/pos
-       integer ncx, nc
-       real*8 temp
-       integer i
-       record /epPos/ posw, posl
-       
-       call epl2w(ncx, pos, posw)
-       do   i=ncx+1, Det.nct
-          call epw2l(i, posw, posl)
-          if(0.d0 .le. posl.z  .and.
-     *        posl.z .le.  Volat( Det.cmp(i).vol + pipeh)) then
-             temp = posl.x**2 +  posl.y**2
-             if(temp .le. Volat( Det.cmp(i).vol + pipeor)**2 .and.
-     *            temp .ge. Volat( Det.cmp(i).vol + pipeir)**2  )   then
-                nc=i
-                goto 101
-             else
-                nc = Det.nct+1
-                goto 101
-             endif
-          endif
-       enddo
-       nc = Det.nct+1
- 101   continue
-       end
-c
-c      ************
-       subroutine  epspipd(ncx, pos, nc)
-c      ************
-       implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-       record /epPos/pos
-       integer ncx, nc
-       real*8 temp
-       integer i
-       record /epPos/ posw, posl
-
-
-c             search downward
-        call epl2w(ncx, pos, posw)
-        do   i=ncx-1, 1, -1
-           call epw2l(i, posw, posl)
-           if(0.d0 .le. posl.z  .and.
-     *          posl.z .le. Volat( Det.cmp(i).vol + pipeh)) then
-              temp = posl.x**2 + posl.y**2 
-              if( temp .le. Volat( Det.cmp(i).vol + pipeor)**2 .and.
-     *            temp .ge. Volat( Det.cmp(i).vol + pipeir)**2)  then
-                 nc=i
-                 goto 201
-              else
-                 nc =  Det.nct+1
-                 goto 201
-              endif
-           endif
-        enddo
-        nc = Det.nct+1
- 201    continue
-       end
+!!c       ************
+!!      subroutine epscyd(ncx, pos, nc)
+!!c       ************
+!!c            pos in l.c
+!!       implicit none
+!!#include  "ZepTrackv.h"
+!!#include  "Zcnfig.h"
+!!       record /epPos/ pos
+!!       integer ncx, nc
+!!       record /epPos/ posw, posl
+!!       integer i
+!!
+!!c             search downward
+!!        call epl2w(ncx, pos, posw)
+!!        do   i=ncx-1, 1, -1
+!!           call epw2l(i, posw, posl)
+!!           if(0.d0 .le. posl.z  .and.
+!!     *              posl.z .le.  Volat( Det.cmp(i).vol + cylh)) then
+!!              if(posl.x**2 + posl.y**2 
+!!     *          .le. Volat( Det.cmp(i).vol + cylr)**2)  then
+!!                 nc=i
+!!                 goto 201
+!!              else
+!!                 nc = Det.nct+1
+!!                 goto 201
+!!              endif
+!!           endif
+!!        enddo
+!!        nc = Det.nct+1
+!! 201    continue
+!!       end
+!!!      ***********************************
+!!       subroutine epspipu(ncx, pos, nc)
+!!c         pos in l.c
+!!       implicit none
+!!#include  "ZepTrackv.h"
+!!#include  "Zcnfig.h"
+!!       record /epPos/pos
+!!       integer ncx, nc
+!!       real*8 temp
+!!       integer i
+!!       record /epPos/ posw, posl
+!!       
+!!       call epl2w(ncx, pos, posw)
+!!       do   i=ncx+1, Det.nct
+!!          call epw2l(i, posw, posl)
+!!          if(0.d0 .le. posl.z  .and.
+!!     *        posl.z .le.  Volat( Det.cmp(i).vol + pipeh)) then
+!!             temp = posl.x**2 +  posl.y**2
+!!             if(temp .le. Volat( Det.cmp(i).vol + pipeor)**2 .and.
+!!     *            temp .ge. Volat( Det.cmp(i).vol + pipeir)**2  )   then
+!!                nc=i
+!!                goto 101
+!!             else
+!!                nc = Det.nct+1
+!!                goto 101
+!!             endif
+!!          endif
+!!       enddo
+!!       nc = Det.nct+1
+!! 101   continue
+!!       end
+!!c
+!!c      ************
+!!       subroutine  epspipd(ncx, pos, nc)
+!!c      ************
+!!       implicit none
+!!#include  "ZepTrackv.h"
+!!#include  "Zcnfig.h"
+!!       record /epPos/pos
+!!       integer ncx, nc
+!!       real*8 temp
+!!       integer i
+!!       record /epPos/ posw, posl
+!!
+!!
+!!c             search downward
+!!        call epl2w(ncx, pos, posw)
+!!        do   i=ncx-1, 1, -1
+!!           call epw2l(i, posw, posl)
+!!           if(0.d0 .le. posl.z  .and.
+!!     *          posl.z .le. Volat( Det.cmp(i).vol + pipeh)) then
+!!              temp = posl.x**2 + posl.y**2 
+!!              if( temp .le. Volat( Det.cmp(i).vol + pipeor)**2 .and.
+!!     *            temp .ge. Volat( Det.cmp(i).vol + pipeir)**2)  then
+!!                 nc=i
+!!                 goto 201
+!!              else
+!!                 nc =  Det.nct+1
+!!                 goto 201
+!!              endif
+!!           endif
+!!        enddo
+!!        nc = Det.nct+1
+!! 201    continue
+!!       end
 c      ********************************
        subroutine  epspipa(pos, nc)
 c      ********************************
@@ -738,11 +759,15 @@ c      ********************************
        integer nc
        real*8 temp
        integer i
-       record /epPos/  posl
+       record /epPos/ posl, post
 
 c             search all
        do   i=1, Det.nct
-          call epw2l(i, pos, posl)
+          call epw2l(i, pos, post)
+c&&&&&
+          call epv2c_pipe(Det.cmp(i), post, posl)
+c&&&&&
+
           if(0.d0 .le. posl.z  .and. 
      *        posl.z .le. Volat( Det.cmp(i).vol + pipeh)) then
              temp = posl.x**2 + posl.y**2 
@@ -802,12 +827,15 @@ c       ************
 #include  "Zcnfig.h"
        record /epPos/ pos
        integer nc
-       record /epPos/ posl
+       record /epPos/ posl, post
        integer i
 
 c             search all
        do   i=1, Det.nct
-          call epw2l(i, pos, posl)
+          call epw2l(i, pos, post)
+c&&&&&
+          call epv2c_cyl(Det.cmp(i), post, posl)
+c&&&&&
           if(0.d0 .le. posl.z  .and. 
      *         Volat( Det.cmp(i).vol + cylh) .ge. posl.z) then
              if( posl.x**2 + posl.y**2 .le.
@@ -823,16 +851,24 @@ c             search all
        nc = Det.nct+1
  301   continue
        end
-       subroutine epspip1(ncx, pos, icon)
+       subroutine epspip1(ncx, posi, icon)
 c         search only ncx-th pipe
 c         xx .. is assumed to be in local coord.
        implicit none
 c       ************
 #include  "ZepTrackv.h"
 #include  "Zcnfig.h"
-       record /epPos/ pos
+       record /epPos/ posi
        integer  icon, ncx
        real*8 temp
+
+       record /epPos/ pos
+
+c  &&&&         convert to canonial one
+        call epv2c_pipe(Det.cmp(ncx), posi, pos)
+c  &&&&&&
+
+
        if(0.d0 .le. pos.z  .and. 
      *         Volat( Det.cmp(ncx).vol + pipeh) .ge. pos.z) then
           temp = pos.x**2 + pos.y**2
@@ -890,23 +926,6 @@ c         pos is assumed to be Local coord.
               icon = 1
            endif
        end
-       subroutine epsprism(ncx, pos, icon)
-c          search specified prism
-c         Is  pos in ncx-th comp.  ? if yes, icon=0 else
-c               icon = 1
-c         pos is assumed to be Local coord.
-       implicit none
-#include  "ZepTrackv.h"
-#include  "Zcnfig.h"
-           record /epPos/ pos
-           integer ncx,  icon
-
-        call kioPrism(pos.x, pos.y, pos.z, 
-     *        Volat( Det.cmp(ncx).vol + prisma),
-     *        Volat( Det.cmp(ncx).vol + prismb),
-     *        Volat( Det.cmp(ncx).vol + prismc),
-     *        Volat( Det.cmp(ncx).vol + prismh), icon)
-       end
        subroutine epw2l(ncx, pos, poso)
 c        world to local conversion
       implicit none
@@ -1125,6 +1144,138 @@ c          and momentum
       else
          poso = pos
       endif
+      end
 
+      subroutine epv2c_cyl(comp, posv, posc)
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ posv ! input
+      record /epPos/ posc ! output. 
+      record /Component/ comp
+      if( comp.struc == "cyl_x") then
+         posc = epPos( posv.z, posv.y, posv.x)
+      elseif(comp.struc == "cyl_y") then
+         posc = epPos( posv.x, posv.z, posv.y)
+      else
+         posc = posv
+      endif
+      end
+      subroutine epc2v_cyl(comp, posc, posv)
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ posc ! input
+      record /epPos/ posv ! output. 
+      record /Component/ comp
+      if( comp.struc == "cyl_x") then
+         posv = epPos( posc.z, posc.y, posc.x)
+      elseif(comp.struc == "cyl_y") then
+         posv = epPos( posc.x, posc.z, posc.y)
+      else
+         posc = posv
+      endif
+      end
+      subroutine epv2cd_cyl(comp, dirv, dirc)
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ dirv ! input
+      record /epPos/ dirc ! output. 
+      record /Component/ comp
+      if( comp.struc == "cyl_x") then
+         dirc = epPos( dirv.z, dirv.y, dirv.x)
+      elseif(comp.struc == "cyl_y") then
+         dirc = epPos( dirv.x, dirv.z, dirv.y)
+      else
+         dirc = dirv
+      endif
+      end
+      subroutine epc2vd_cyl(comp, dirc, dirv)
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ dirc ! input
+      record /epPos/ dirv ! output. 
+      record /Component/ comp
+      if( comp.struc == "cyl_x") then
+         dirv = epPos( dirc.z, dirc.y, dirc.x)
+      elseif(comp.struc == "cyl_y") then
+         dirv = epPos( dirc.x, dirc.z, dirc.y)
+      else
+         dirv = dirc
+      endif
+      end
 
+      subroutine epv2c_pipe(comp, posv, posc)
+!           variant local to canonical local; used when
+!           manipulating things in canonical local
+!          (for boundary search etc).  system normally recognizes
+!           variant local as usual local 
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ posv ! input
+      record /epPos/ posc ! output. 
+      record /Component/ comp
+      if( comp.struc == "pipe_x") then
+         posc = epPos( posv.z, posv.y, posv.x)
+      elseif(comp.struc == "pipe_y") then
+         posc = epPos( posv.x, posv.z, posv.y)
+      else
+         posc = posv
+      endif
+      end
+      subroutine epc2v_pipe(comp, posc, posv)
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ posc ! input
+      record /epPos/ posv ! output. 
+      record /Component/ comp
+      if( comp.struc == "pipe_x") then
+         posv = epPos( posc.z, posc.y, posc.x)
+      elseif(comp.struc == "pipe_y") then
+         posv = epPos( posc.x, posc.z, posc.y)
+      else
+         posc = posv
+      endif
+      end
+      subroutine epv2cd_pipe(comp, dirv, dirc)
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ dirv ! input
+      record /epPos/ dirc ! output. 
+      record /Component/ comp
+      if( comp.struc == "pipe_x") then
+         dirc = epPos( dirv.z, dirv.y, dirv.x)
+      elseif(comp.struc == "pipe_y") then
+         dirc = epPos( dirv.x, dirv.z, dirv.y)
+      else
+         dirc = dirv
+      endif
+      end
+      subroutine epc2vd_pipe(comp, dirc, dirv)
+      implicit none
+#include "Zep3Vec.h"
+#include  "Zcnfig.h"
+#include  "ZepPos.h"
+      record /epPos/ dirc ! input
+      record /epPos/ dirv ! output. 
+      record /Component/ comp
+      if( comp.struc == "pipe_x") then
+         dirv = epPos( dirc.z, dirc.y, dirc.x)
+      elseif(comp.struc == "pipe_y") then
+         dirv = epPos( dirc.x, dirc.z, dirc.y)
+      else
+         dirv = dirc
+      endif
       end
